@@ -17,6 +17,7 @@
 ** not clear to you.
 **
 **********************************************************************/
+#include <scriptobject.h>
 #include "command.h"
 #include "formwindow.h"
 #include "widgetfactory.h"
@@ -30,6 +31,7 @@
 #include "actiondnd.h"
 #include "formfile.h"
 
+#include <qmap.h>
 #include <qfeatures.h>
 #include <qwidget.h>
 #include <qmetaobject.h>
@@ -46,6 +48,9 @@
 #endif
 #include <qaction.h>
 
+#include <klocale.h>
+
+
 CommandHistory::CommandHistory( int s )
     : current( -1 ), steps( s ), savedAt( -1 )
 {
@@ -219,6 +224,63 @@ bool Command::canMerge( Command * )
 
 // ------------------------------------------------------------
 
+ScriptObjectCommand::ScriptObjectCommand(const QString &a_name, FormWindow *a_fw, QMap<QString, QString> a_oldObjects, QMap<QString, QString> a_newObjects)
+: Command(a_name, a_fw), m_oldObjects(a_oldObjects), m_newObjects(a_newObjects)
+{
+}
+
+ScriptObjectCommand::~ScriptObjectCommand()
+{
+}
+
+void ScriptObjectCommand::execute()
+{
+	removeScriptObjects();
+	addScriptObjects(m_newObjects);
+}
+
+void ScriptObjectCommand::unexecute()
+{
+	removeScriptObjects();
+	addScriptObjects(m_oldObjects);
+}
+
+void ScriptObjectCommand::addScriptObjects(QMap<QString, QString> a_objects)
+{
+	QMap<QString, QString>::Iterator it;
+	for(it = a_objects.begin();it != a_objects.end();++it)
+	{
+		ScriptObject *obj;
+		obj = (ScriptObject *)WidgetFactory::create(WidgetDatabase::idFromClassName("ScriptObject"), formWindow()->mainContainer(), it.key(), FALSE);
+		obj->setWidgetText(it.data());
+
+		formWindow()->insertWidget(obj, FALSE);
+
+		MetaDataBase::setPropertyChanged(obj, "script", TRUE);
+	}
+
+}
+
+void ScriptObjectCommand::removeScriptObjects()
+{
+	QObjectList *ol = formWindow()->mainContainer()->queryList();
+
+	if(ol)
+	{
+		QObject *obj = ol->first();
+		for(;obj;obj = ol->next())
+		{
+			if(obj->isA("ScriptObject"))
+			{
+				delete obj; // delete this script object
+			}
+		}
+		delete ol;
+	}
+}
+
+// ------------------------------------------------------------
+
 ResizeCommand::ResizeCommand( const QString &n, FormWindow *fw,
 			      QWidget *w, const QRect &oldr, const QRect &nr )
     : Command( n, fw ), widget( w ), oldRect( oldr ), newRect( nr )
@@ -490,10 +552,10 @@ bool SetPropertyCommand::checkProperty()
 	QString s = newValue.toString();
 	if ( !formWindow()->unify( widget, s, FALSE ) ) {
 	    QMessageBox::information( formWindow()->mainWindow(),
-				      FormWindow::tr( "Set 'name' property" ),
-				      FormWindow::tr( "The name of a widget must be unique.\n"
-						      "'%1' is already used in form '%2',\n"
-						      "so the name has been reverted to '%3'." ).
+				      i18n( "Set 'name' Property" ),
+				      i18n( "The name of a widget must be unique.\n"
+                            "'%1' is already used in form '%2',\n"
+                            "so the name has been reverted to '%3'." ).
 				      arg( newValue.toString() ).
 				      arg( formWindow()->name() ).
 				      arg( oldValue.toString() ));
@@ -502,9 +564,9 @@ bool SetPropertyCommand::checkProperty()
 	}
 	if ( s.isEmpty() ) {
 	    QMessageBox::information( formWindow()->mainWindow(),
-				      FormWindow::tr( "Set 'name' property" ),
-				      FormWindow::tr( "The name of a widget must not be null.\n"
-						      "The name has been reverted to '%1'." ).
+				      i18n( "Set 'name' Property" ),
+				      i18n( "The name of a widget must not be null.\n"
+                            "The name has been reverted to '%1'." ).
 				      arg( oldValue.toString() ));
 	    setProperty( oldValue, oldCurrentItemText, FALSE );
 	    return FALSE;
@@ -1000,16 +1062,26 @@ void AddConnectionCommand::execute()
 {
     MetaDataBase::addConnection( formWindow(), connection.sender,
 				 connection.signal, connection.receiver, connection.slot );
+#ifndef KOMMANDER
     if ( connection.receiver == formWindow()->mainContainer() )
+    {
+	qDebug("AddConnectionCommand::execute(): Would have called EventList::setup()");
 	formWindow()->mainWindow()->propertyeditor()->eventList()->setup();
+    }
+#endif
 }
 
 void AddConnectionCommand::unexecute()
 {
     MetaDataBase::removeConnection( formWindow(), connection.sender,
 				    connection.signal, connection.receiver, connection.slot );
+#ifndef KOMMANDER
     if ( connection.receiver == formWindow()->mainContainer() )
+    {
+	qDebug("AddConnectionCommand::unexecute(): Would have called EventList::setup()");
 	formWindow()->mainWindow()->propertyeditor()->eventList()->setup();
+    }
+#endif
 }
 
 // ------------------------------------------------------------
@@ -1024,30 +1096,44 @@ void RemoveConnectionCommand::execute()
 {
     MetaDataBase::removeConnection( formWindow(), connection.sender,
 				    connection.signal, connection.receiver, connection.slot );
+#ifndef KOMMANDER
     if ( connection.receiver == formWindow()->mainContainer() )
+    {
+        qDebug("RemoveConnectionCommand::execute(): Would have called EventList::setup()");
 	formWindow()->mainWindow()->propertyeditor()->eventList()->setup();
+    }
+#endif
 }
 
 void RemoveConnectionCommand::unexecute()
 {
     MetaDataBase::addConnection( formWindow(), connection.sender,
 				 connection.signal, connection.receiver, connection.slot );
+#ifndef KOMMANDER
     if ( connection.receiver == formWindow()->mainContainer() )
+    {
+        qDebug("RemoveConnectionCommand::unexecute(): Would have called EventList::setup()");
 	formWindow()->mainWindow()->propertyeditor()->eventList()->setup();
+    }
+#endif
 }
 
 // ------------------------------------------------------------
 
+/* TODO : We don't need these commands. */
 AddSlotCommand::AddSlotCommand( const QString &name, FormWindow *fw, const QCString &s,
 				const QString& spec, const QString &a, const QString &l, const QString &rt )
     : Command( name, fw ), slot( s ), specifier( spec ), access( a ), language( l ), returnType( rt )
 {
+	qDebug("AddSlotCommand::AddSlotCommand()");
 }
 
 void AddSlotCommand::execute()
 {
     MetaDataBase::addSlot( formWindow(), slot, specifier, access, language, returnType );
+#ifndef KOMMANDER
     formWindow()->mainWindow()->slotsChanged();
+#endif
     if ( formWindow()->formFile() )
 	formWindow()->formFile()->setModified( TRUE );
 }
@@ -1055,7 +1141,9 @@ void AddSlotCommand::execute()
 void AddSlotCommand::unexecute()
 {
     MetaDataBase::removeSlot( formWindow(), slot, specifier, access, language, returnType );
+#ifndef KOMMANDER
     formWindow()->mainWindow()->slotsChanged();
+#endif
     if ( formWindow()->formFile() )
 	formWindow()->formFile()->setModified( TRUE );
 }
@@ -1066,12 +1154,15 @@ RemoveSlotCommand::RemoveSlotCommand( const QString &name, FormWindow *fw, const
 				      const QString& spec, const QString &a, const QString &l, const QString &rt )
     : Command( name, fw ), slot( s ), specifier( spec ), access( a ), language( l ), returnType( rt )
 {
+	qDebug("RemoveSlotCommand::RemoveSlotCommand()");
 }
 
 void RemoveSlotCommand::execute()
 {
     MetaDataBase::removeSlot( formWindow(), slot, specifier, access, language, returnType );
+#ifndef KOMMANDER
     formWindow()->mainWindow()->slotsChanged();
+#endif
     if ( formWindow()->formFile() )
 	formWindow()->formFile()->setModified( TRUE );
 }
@@ -1079,7 +1170,9 @@ void RemoveSlotCommand::execute()
 void RemoveSlotCommand::unexecute()
 {
     MetaDataBase::addSlot( formWindow(), slot, specifier, access, language, returnType );
+#ifndef KOMMANDER
     formWindow()->mainWindow()->slotsChanged();
+#endif
     if ( formWindow()->formFile() )
 	formWindow()->formFile()->setModified( TRUE );
 }
