@@ -31,19 +31,26 @@
 #include "pixmapchooser.h"
 #include "orderindicator.h"
 #include "hierarchyview.h"
+
+#ifndef KOMMANDER
 #include "designerappiface.h"
-#define NO_STATIC_COLORS
+#endif
+
+//#define NO_STATIC_COLORS
 #include "globaldefs.h"
 #include "formfile.h"
+#include <scriptobject.h>
 
 #include <stdlib.h>
 
+#include <qmap.h>
 #include <qevent.h>
 #include <qpainter.h>
 #include <qpen.h>
 #include <qlabel.h>
 #include <qobjectlist.h>
 #include <qtimer.h>
+#include <qapplication.h>
 #include <qlayout.h>
 #include <qspinbox.h>
 #include <qstatusbar.h>
@@ -59,12 +66,13 @@
 #include <qaccel.h>
 #include <qpixmapcache.h>
 #include <qbitmap.h>
-#include <qapplication.h>
 
 #ifdef HAVE_KDE
 #include <kstatusbar.h>
 #endif
 
+#include <klocale.h>
+
 static void setCursorToAll( const QCursor &c, QWidget *start )
 {
     start->setCursor( c );
@@ -145,8 +153,8 @@ void FormWindow::init()
 {
     MetaDataBase::addEntry( this );
     ff->setFormWindow( this );
-    iface = 0;
 #ifndef KOMMANDER
+    iface = 0;
     proj = 0;
 #endif
     propertyWidget = 0;
@@ -242,7 +250,9 @@ FormWindow::~FormWindow()
     MetaDataBase::clear( this );
     if ( ff )
 	ff->setFormWindow( 0 );
+#ifndef KOMMANDER
     delete iface;
+#endif
 }
 
 void FormWindow::closeEvent( QCloseEvent *e )
@@ -358,8 +368,8 @@ void FormWindow::insertWidget()
     QString n = WidgetDatabase::className( currTool );
     if (  useSizeHint && ( n == "Spacer" || n == "QSlider" || n == "Line" || n == "QScrollBar" ) ) {
 	QPopupMenu m( mainWindow() );
-	m.insertItem( tr( "&Horizontal" ) );
-	int ver = m.insertItem( tr( "&Vertical" ) );
+	m.insertItem( i18n( "&Horizontal" ) );
+	int ver = m.insertItem( i18n( "&Vertical" ) );
 	int r = m.exec( QCursor::pos() );
 	if ( r == ver )
 	    orient = Vertical;
@@ -374,14 +384,14 @@ void FormWindow::insertWidget()
 	( (QLabel*)w )->setPixmap( PixmapChooser::loadPixmap( "image.xpm" ) );
     int id = WidgetDatabase::idFromClassName( WidgetFactory::classNameOf(w) );
     if ( WidgetDatabase::isCustomWidget( id ) ) {
-	QWhatsThis::add( w, tr("<b>A %1 (custom widget)</b> "
+	QWhatsThis::add( w, i18n("<b>A %1 (custom widget)</b> "
 			    "<p>Click <b>Edit Custom Widgets...</b> in the <b>Tools|Custom</b> "
 			    "menu to add and change custom widgets. You can add "
 			    "properties as well as signals and slots to integrate custom widgets into "
 			    "<i>Qt Designer</i>, and provide a pixmap which will be used to represent "
 			    "the widget on the form.</p>")
 			    .arg(WidgetDatabase::toolTip( id )) );
-	QToolTip::add( w, tr("A %1 (custom widget)").arg(WidgetDatabase::toolTip( id )) );
+	QToolTip::add( w, i18n("A %1 (custom widget)").arg(WidgetDatabase::toolTip( id )) );
     } else {
 	QString tt = WidgetDatabase::toolTip( id );
 	QString wt = WidgetDatabase::whatsThis( id );
@@ -441,20 +451,20 @@ void FormWindow::insertWidget()
 	    np.append( pos );
 	}
 
-	MoveCommand *mv = new MoveCommand( tr( "Reparent Widgets" ), this, lst, op, np, insertParent, pw );
+	MoveCommand *mv = new MoveCommand( i18n( "Reparent Widgets" ), this, lst, op, np, insertParent, pw );
 
 	if ( !toolFixed )
 	    mainwindow->resetTool();
 	else
 	    setCursorToAll( CrossCursor, w );
 
-	InsertCommand *cmd = new InsertCommand( tr( "Insert %1" ).arg( w->name() ), this, w, r );
+	InsertCommand *cmd = new InsertCommand( i18n( "Insert %1" ).arg( w->name() ), this, w, r );
 
 	QPtrList<Command> commands;
 	commands.append( mv );
 	commands.append( cmd );
 
-	MacroCommand *mc = new MacroCommand( tr( "Insert %1" ).arg( w->name() ), this, commands );
+	MacroCommand *mc = new MacroCommand( i18n( "Insert %1" ).arg( w->name() ), this, commands );
 	commandHistory()->addCommand( mc );
 	mc->execute();
     } else {
@@ -463,16 +473,18 @@ void FormWindow::insertWidget()
 	else
 	    setCursorToAll( CrossCursor, w );
 
-	InsertCommand *cmd = new InsertCommand( tr( "Insert %1" ).arg( w->name() ), this, w, r );
+	InsertCommand *cmd = new InsertCommand( i18n( "Insert %1" ).arg( w->name() ), this, w, r );
 	commandHistory()->addCommand( cmd );
 	cmd->execute();
     }
 
+#ifndef KOMMANDER
     TemplateWizardInterface *iface = mainWindow()->templateWizardInterface( w->className() );
     if ( iface ) {
 	iface->setup( w->className(), w, iFace(), mainWindow()->designerInterface() );
 	iface->release();
     }
+#endif
 }
 
 void FormWindow::insertWidget( QWidget *w, bool checkName )
@@ -486,14 +498,14 @@ void FormWindow::insertWidget( QWidget *w, bool checkName )
     MetaDataBase::addEntry( w );
     int id = WidgetDatabase::idFromClassName( WidgetFactory::classNameOf(w) );
     if ( WidgetDatabase::isCustomWidget( id ) ) {
-	QWhatsThis::add( w, tr("<b>A %1 (custom widget)</b> "
+	QWhatsThis::add( w, i18n("<b>A %1 (custom widget)</b> "
 			    "<p>Click <b>Edit Custom Widgets...</b> in the <b>Tools|Custom</b> "
 			    "menu to add and change custom widgets. You can add "
 			    "properties as well as signals and slots to integrate custom widgets into "
 			    "<i>Qt Designer</i>, and provide a pixmap which will be used to represent "
 			    "the widget on the form.</p>")
 			    .arg(WidgetDatabase::toolTip( id )) );
-	QToolTip::add( w, tr("A %1 (custom widget)").arg(WidgetDatabase::toolTip( id )) );
+	QToolTip::add( w, i18n("A %1 (custom widget)").arg(WidgetDatabase::toolTip( id )) );
     } else {
 	QString tt = WidgetDatabase::toolTip( id );
 	QString wt = WidgetDatabase::whatsThis( id );
@@ -635,7 +647,7 @@ void FormWindow::handleMousePress( QMouseEvent *e, QWidget *w )
 	if ( e->button() != LeftButton )
 	    break;
 	saveBackground();
-	mainWindow()->statusBar()->message( tr( "Connect '%1' with..." ).arg( w->name() ) );
+	mainWindow()->statusBar()->message( i18n( "Connect '%1' with..." ).arg( w->name() ) );
 	connectStartPos = mapFromGlobal( e->globalPos() );
 	currentConnectPos = mapFromGlobal( e->globalPos() );
 	connectSender = designerWidget( w );
@@ -655,7 +667,7 @@ void FormWindow::handleMousePress( QMouseEvent *e, QWidget *w )
 		}
 	    }
 	    QWidgetList oldl = MetaDataBase::tabOrder( this );
-	    TabOrderCommand *cmd = new TabOrderCommand( tr( "Change Tab Order" ), this, oldl, stackedWidgets );
+	    TabOrderCommand *cmd = new TabOrderCommand( i18n( "Change Tab Order" ), this, oldl, stackedWidgets );
 	    cmd->execute();
 	    commandHistory()->addCommand( cmd, TRUE );
 	    updateOrderIndicators();
@@ -700,7 +712,7 @@ void FormWindow::handleMouseDblClick( QMouseEvent *, QWidget *w )
 		}
 	    }
 	    QWidgetList oldl = MetaDataBase::tabOrder( this );
-	    TabOrderCommand *cmd = new TabOrderCommand( tr( "Change Tab Order" ), this, oldl, stackedWidgets );
+	    TabOrderCommand *cmd = new TabOrderCommand( i18n( "Change Tab Order" ), this, oldl, stackedWidgets );
 	    cmd->execute();
 	    commandHistory()->addCommand( cmd, TRUE );
 	    updateOrderIndicators();
@@ -808,7 +820,7 @@ void FormWindow::handleMouseMove( QMouseEvent *e, QWidget *w )
 
 		// finally move the selected widgets and show/update preview label
 		moveSelectedWidgets( x - p.x(), y - p.y() );
-		sizePreviewLabel->setText( tr( "%1/%2" ).arg( w->pos().x() ).arg( w->pos().y() ) );
+		sizePreviewLabel->setText( QString( "%1/%2" ).arg( w->pos().x() ).arg( w->pos().y() ) );
 		sizePreviewLabel->adjustSize();
 		QRect lg( mapFromGlobal( e->globalPos() ) + QPoint( 16, 16 ), sizePreviewLabel->size() );
 		checkPreviewGeometry( lg );
@@ -844,7 +856,7 @@ void FormWindow::handleMouseMove( QMouseEvent *e, QWidget *w )
 	if ( newReceiver &&
 	     ( isMainContainer( newReceiver ) || insertedWidgets.find( newReceiver ) ) && !isCentralWidget( newReceiver ) )
 	    connectReceiver = connectableObject( newReceiver, connectReceiver );
-	mainWindow()->statusBar()->message( tr( "Connect '%1' to '%2'" ).arg( connectSender->name() ).
+	mainWindow()->statusBar()->message( i18n( "Connect '%1' to '%2'" ).arg( connectSender->name() ).
 					    arg( connectReceiver->name() ) );
 	qApp->processEvents();
 	if ( drawRecRect )
@@ -901,15 +913,15 @@ void FormWindow::handleMouseRelease( QMouseEvent *e, QWidget *w )
 
 		// break layout if necessary
 		if ( WidgetFactory::layoutType( wa ) != WidgetFactory::NoLayout ) {
-		    if ( QMessageBox::information( mainWindow(), tr( "Inserting a Widget" ),
-						   tr( "You tried to insert a widget into the "
+		    if ( QMessageBox::information( mainWindow(), i18n( "Inserting a Widget" ),
+						   i18n( "You tried to insert a widget into the "
 						       "layout Container Widget '%1'.\n"
 						       "This is not possible. "
 						       "In order to insert the widget, the layout of '%1'\n"
 						       "must first be broken.\n"
 						       "Break the layout or cancel the operation?" ).
 						   arg( wa->name() ).
-						   arg( wa->name() ), tr( "&Break Layout" ), tr( "&Cancel" ) ) )
+						   arg( wa->name() ), i18n( "&Break Layout" ), i18n( "&Cancel" ) ) )
 			goto make_move_command; // cancel
 		    breakLayout( wa );
 		}
@@ -952,7 +964,7 @@ void FormWindow::handleMouseRelease( QMouseEvent *e, QWidget *w )
 		newPos.append( ( (QWidget*)it.key() )->pos() );
 	    }
 	    // add move command, don't execute it, this is just a summary of the operations we did during the move-event handling
-	    commandHistory()->addCommand( new MoveCommand( tr( "Move" ),
+	    commandHistory()->addCommand( new MoveCommand( i18n( "Move" ),
 							   this, widgets,
 							   oldPos, newPos, oldParent, newParent ) );
 	} else if ( drawRubber ) { // we were drawing a rubber selection
@@ -986,15 +998,15 @@ void FormWindow::handleMouseRelease( QMouseEvent *e, QWidget *w )
 	if ( insertParent ) { // we should insert the new widget now
 	    endRectDraw();
 	    if ( WidgetFactory::layoutType( insertParent ) != WidgetFactory::NoLayout ) {
-		if ( QMessageBox::information( mainWindow(), tr( "Inserting a Widget" ),
-					       tr( "You tried to insert a widget into the "
+		if ( QMessageBox::information( mainWindow(), i18n( "Inserting a Widget" ),
+					       i18n( "You tried to insert a widget into the "
 						   "layout Container Widget '%1'.\n"
 						   "This is not possible. "
 						   "In order to insert the widget, the layout of '%1'\n"
 						   "must first be broken.\n"
 						   "Break the layout or cancel the operation?" ).
 					       arg( insertParent->name() ).
-					       arg( insertParent->name() ), tr( "&Break Layout" ), tr( "&Cancel" ) ) == 0 ) {
+					       arg( insertParent->name() ), i18n( "&Break Layout" ), i18n( "&Cancel" ) ) == 0 ) {
 		    breakLayout( insertParent );
 		} else {
 		    if ( !toolFixed )
@@ -1073,7 +1085,7 @@ void FormWindow::handleKeyPress( QKeyEvent *e, QWidget *w )
 	    }
 	}
 	if ( !widgets.isEmpty() ) {
-	    MoveCommand *cmd = new MoveCommand( tr( "Move" ), this,
+	    MoveCommand *cmd = new MoveCommand( i18n( "Move" ), this,
 						widgets, oldPos, newPos, 0, 0 );
 	    commandHistory()->addCommand( cmd, TRUE );
 	    cmd->execute();
@@ -1230,7 +1242,7 @@ void FormWindow::startRectDraw( const QPoint &p, const QPoint &global, QWidget *
 	rectAnchor = pos;
     currRect = QRect( rectAnchor, QPoint( 0, 0 ) );
     if ( t == Insert )
-	drawSizePreview( pos, tr("Use Size Hint") );
+	drawSizePreview( pos, i18n("Use Size Hint") );
 }
 
 void FormWindow::continueRectDraw( const QPoint &p, const QPoint &global, QWidget *, RectType t )
@@ -1246,7 +1258,7 @@ void FormWindow::continueRectDraw( const QPoint &p, const QPoint &global, QWidge
     r = r.normalize();
 
     if ( currRect == r ) {
-	QString t = tr( "%1/%2" );
+	QString t( "%1/%2" );
 	t = t.arg( r.width() - 1 ).arg( r.height() - 1 );
 	drawSizePreview( pos, t );
 	return;
@@ -1258,7 +1270,7 @@ void FormWindow::continueRectDraw( const QPoint &p, const QPoint &global, QWidge
 	oldRectValid = TRUE;
 	currRect = r;
 	if ( t == Insert ) {
-	    QString t = tr( "%1/%2" );
+	    QString t( "%1/%2" );
 	    t = t.arg( r.width() - 1 ).arg( r.height() - 1 );
 	    drawSizePreview( pos, t );
 	}
@@ -1268,7 +1280,7 @@ void FormWindow::continueRectDraw( const QPoint &p, const QPoint &global, QWidge
     } else {
 	oldRectValid = FALSE;
 	if ( t == Insert )
-	    drawSizePreview( pos, tr("Use Size Hint") );
+	    drawSizePreview( pos, i18n("Use Size Hint") );
     }
 }
 
@@ -1411,7 +1423,7 @@ void FormWindow::deleteWidgets()
     if ( widgets.isEmpty() )
 	return;
 
-    DeleteCommand *cmd = new DeleteCommand( tr( "Delete" ), this, widgets );
+    DeleteCommand *cmd = new DeleteCommand( i18n( "Delete" ), this, widgets );
     commandHistory()->addCommand( cmd );
     cmd->execute();
 }
@@ -1429,7 +1441,7 @@ void FormWindow::editAdjustSize()
 	    mainContainer()->resize( size() );
 	QRect nr = geometry();
 	if ( oldr != nr ) {
-	    ResizeCommand *cmd = new ResizeCommand( tr( "Adjust Size" ), this, this, oldr, nr );
+	    ResizeCommand *cmd = new ResizeCommand( i18n( "Adjust Size" ), this, this, oldr, nr );
 	    commandHistory()->addCommand( cmd );
 	}
 	return;
@@ -1441,7 +1453,7 @@ void FormWindow::editAdjustSize()
 	w->adjustSize();
 	QRect nr = w->geometry();
 	if ( oldr != nr )
-	    commands.append( new ResizeCommand( tr("Adjust Size"), this, w, oldr, nr ) );
+	    commands.append( new ResizeCommand( i18n("Adjust Size"), this, w, oldr, nr ) );
     }
 
     if ( commands.isEmpty() )
@@ -1449,7 +1461,7 @@ void FormWindow::editAdjustSize()
     for ( WidgetSelection *s = selections.first(); s; s = selections.next() )
 	s->updateGeometry();
 
-    MacroCommand *cmd = new MacroCommand( tr( "Adjust Size" ), this, commands );
+    MacroCommand *cmd = new MacroCommand( i18n( "Adjust Size" ), this, commands );
     commandHistory()->addCommand( cmd );
 }
 
@@ -1520,7 +1532,11 @@ void FormWindow::resizeEvent( QResizeEvent *e )
     if ( currTool == ORDER_TOOL )
 	repositionOrderIndicators();
     if ( isVisible() )
+#ifndef KOMMANDER
 	formFile()->setModified( TRUE, FormFile::WFormWindow );
+#else
+    	formFile()->setModified( TRUE );
+#endif
 
 #if defined(Q_WS_WIN32)
     windowsRepaintWorkaroundTimer->start( 100, TRUE );
@@ -1652,7 +1668,7 @@ void FormWindow::currentToolChanged()
 	break;
     case ORDER_TOOL:
 	if ( mainWindow()->formWindow() == this ) {
-	    mainWindow()->statusBar()->message( tr( "Click widgets to change the tab order...") );
+	    mainWindow()->statusBar()->message( i18n( "Click widgets to change the tab order...") );
 	    orderedWidgets.clear();
 	    showOrderIndicators();
 	    if ( mainWindow()->formWindow() == this )
@@ -1661,13 +1677,13 @@ void FormWindow::currentToolChanged()
 	}
 	break;
     case CONNECT_TOOL:
-	mainWindow()->statusBar()->message( tr( "Drag a line to create a connection...") );
+	mainWindow()->statusBar()->message( i18n( "Drag a line to create a connection...") );
 	setCursorToAll( CrossCursor, this );
 	if ( mainWindow()->formWindow() == this )
 	    emitShowProperties( mainContainer() );
 	break;
     default:
-	mainWindow()->statusBar()->message( tr( "Click on the form to insert a %1..." ).arg( WidgetDatabase::toolTip( currTool ).lower() ) );
+	mainWindow()->statusBar()->message( i18n( "Click on the form to insert a %1..." ).arg( WidgetDatabase::toolTip( currTool ).lower() ) );
 	setCursorToAll( CrossCursor, this );
 	if ( mainWindow()->formWindow() == this )
 	    emitShowProperties( mainContainer() );
@@ -1739,14 +1755,14 @@ bool FormWindow::checkCustomWidgets()
     }
 
     if ( !missingCustomWidgets.isEmpty() ) {
-	QString txt = tr( "The following custom widgets are used in '%1',\n"
+	QString txt = i18n( "The following custom widgets are used in '%1',\n"
 			  "but are not known to Qt Designer:\n" ).arg( name() );
 	for ( QStringList::Iterator sit = missingCustomWidgets.begin(); sit != missingCustomWidgets.end(); ++sit )
 	    txt += "   " + *sit + "\n";
-	txt += "If you save this form and generate code for it using uic, \n"
+	txt += i18n("If you save this form and generate code for it using uic, \n"
 	       "the generated code will not compile.\n"
-	       "Do you want to save this form now?";
-	if ( QMessageBox::information( mainWindow(), tr( "Save Form" ), txt ) == 1 )
+	       "Do you want to save this form now?");
+	if ( QMessageBox::information( mainWindow(), i18n( "Save Form" ), txt ) == 1 )
 	    return FALSE;
     }
     return TRUE;
@@ -1781,7 +1797,7 @@ void FormWindow::lowerWidgets()
     for ( ; it.current(); ++it )
 	widgets.append( it.current()->widget() );
 
-    LowerCommand *cmd = new LowerCommand( tr( "Lower" ), this, widgets );
+    LowerCommand *cmd = new LowerCommand( i18n( "Lower" ), this, widgets );
     cmd->execute();
     commandHistory()->addCommand( cmd );
 }
@@ -1837,11 +1853,11 @@ void FormWindow::checkAccels()
     for ( QMap<QChar, QWidgetList >::Iterator it = accels.begin(); it != accels.end(); ++it ) {
 	if ( (*it).count() > 1 ) {
 	    ok = FALSE;
-	    switch ( QMessageBox::information( mainWindow(), tr( "Check Accelerators" ),
-					       tr( "Accelerator '%1' is used %2 times."
+	    switch ( QMessageBox::information( mainWindow(), i18n( "Check Accelerators" ),
+					       i18n( "Accelerator '%1' is used %2 times."
 						   ).arg( it.key().upper() ).arg( (*it).count() ),
-					       tr( "&Select" ),
-					       tr( "&Cancel" ), 0, 2 ) ) {
+					       i18n( "&Select" ),
+					       i18n( "&Cancel" ), 0, 2 ) ) {
 	    case 0: // select
 		clearSelection( FALSE );
 		for ( wid = (*it).first(); wid; wid = (*it).next() )
@@ -1854,8 +1870,8 @@ void FormWindow::checkAccels()
     }
 
     if ( ok )
-	QMessageBox::information( mainWindow(), tr( "Check Accelerators" ),
-				  tr( "No accelerator is used more than once." ) );
+	QMessageBox::information( mainWindow(), i18n( "Check Accelerators" ),
+				  i18n( "No accelerator is used more than once." ) );
 }
 
 void FormWindow::raiseWidgets()
@@ -1865,7 +1881,7 @@ void FormWindow::raiseWidgets()
     for ( ; it.current(); ++it )
 	widgets.append( it.current()->widget() );
 
-    RaiseCommand *cmd = new RaiseCommand( tr( "Raise" ), this, widgets );
+    RaiseCommand *cmd = new RaiseCommand( i18n( "Raise" ), this, widgets );
     cmd->execute();
     commandHistory()->addCommand( cmd );
 }
@@ -1902,7 +1918,7 @@ void FormWindow::selectAll()
 void FormWindow::layoutHorizontal()
 {
     QWidgetList widgets( selectedWidgets() );
-    LayoutHorizontalCommand *cmd = new LayoutHorizontalCommand( tr( "Lay out horizontally" ),
+    LayoutHorizontalCommand *cmd = new LayoutHorizontalCommand( i18n( "Lay Out Horizontally" ),
 								this, mainContainer(), 0, widgets );
     clearSelection( FALSE );
     commandHistory()->addCommand( cmd );
@@ -1912,7 +1928,7 @@ void FormWindow::layoutHorizontal()
 void FormWindow::layoutVertical()
 {
     QWidgetList widgets( selectedWidgets() );
-    LayoutVerticalCommand *cmd = new LayoutVerticalCommand( tr( "Lay out vertically" ),
+    LayoutVerticalCommand *cmd = new LayoutVerticalCommand( i18n( "Lay Out Vertically" ),
 							    this, mainContainer(), 0, widgets );
     clearSelection( FALSE );
     commandHistory()->addCommand( cmd );
@@ -1922,7 +1938,7 @@ void FormWindow::layoutVertical()
 void FormWindow::layoutHorizontalSplit()
 {
     QWidgetList widgets( selectedWidgets() );
-    LayoutHorizontalSplitCommand *cmd = new LayoutHorizontalSplitCommand( tr( "Lay out horizontally (in splitter)" ),
+    LayoutHorizontalSplitCommand *cmd = new LayoutHorizontalSplitCommand( i18n( "Lay Out Horizontally (in splitter)" ),
 									  this, mainContainer(), 0, widgets );
     clearSelection( FALSE );
     commandHistory()->addCommand( cmd );
@@ -1932,7 +1948,7 @@ void FormWindow::layoutHorizontalSplit()
 void FormWindow::layoutVerticalSplit()
 {
     QWidgetList widgets( selectedWidgets() );
-    LayoutVerticalSplitCommand *cmd = new LayoutVerticalSplitCommand( tr( "Lay out vertically (in splitter)" ),
+    LayoutVerticalSplitCommand *cmd = new LayoutVerticalSplitCommand( i18n( "Lay Out Vertically (in splitter)" ),
 								      this, mainContainer(), 0, widgets );
     clearSelection( FALSE );
     commandHistory()->addCommand( cmd );
@@ -1945,7 +1961,7 @@ void FormWindow::layoutGrid()
     int yres = grid().y();
 
     QWidgetList widgets( selectedWidgets() );
-    LayoutGridCommand *cmd = new LayoutGridCommand( tr( "Lay out in a grid" ),
+    LayoutGridCommand *cmd = new LayoutGridCommand( i18n( "Lay Out in a Grid" ),
 						    this, mainContainer(), 0, widgets, xres, yres );
     clearSelection( FALSE );
     commandHistory()->addCommand( cmd );
@@ -1966,7 +1982,7 @@ void FormWindow::layoutHorizontalContainer( QWidget *w )
 	     insertedWidgets.find( (QWidget*)o ) )
 	    widgets.append( (QWidget*)o );
     }
-    LayoutHorizontalCommand *cmd = new LayoutHorizontalCommand( tr( "Lay out children horizontally" ),
+    LayoutHorizontalCommand *cmd = new LayoutHorizontalCommand( i18n( "Lay Out Children Horizontally" ),
 								this, mainContainer(), w, widgets );
     clearSelection( FALSE );
     commandHistory()->addCommand( cmd );
@@ -1987,7 +2003,7 @@ void FormWindow::layoutVerticalContainer( QWidget *w )
 	     insertedWidgets.find( (QWidget*)o ) )
 	    widgets.append( (QWidget*)o );
     }
-    LayoutVerticalCommand *cmd = new LayoutVerticalCommand( tr( "Lay out children vertically" ),
+    LayoutVerticalCommand *cmd = new LayoutVerticalCommand( i18n( "Lay Out Children Vertically" ),
 							    this, mainContainer(), w, widgets );
     clearSelection( FALSE );
     commandHistory()->addCommand( cmd );
@@ -2011,7 +2027,7 @@ void FormWindow::layoutGridContainer( QWidget *w )
 	     insertedWidgets.find( (QWidget*)o ) )
 	    widgets.append( (QWidget*)o );
     }
-    LayoutGridCommand *cmd = new LayoutGridCommand( tr( "Lay out children in a grid" ),
+    LayoutGridCommand *cmd = new LayoutGridCommand( i18n( "Lay Out Children in a Grid" ),
 						    this, mainContainer(), w, widgets, xres, yres );
     clearSelection( FALSE );
     commandHistory()->addCommand( cmd );
@@ -2020,7 +2036,6 @@ void FormWindow::layoutGridContainer( QWidget *w )
 
 void FormWindow::breakLayout( QWidget *w )
 {
-	fprintf(stderr, "FormWindow::breakLayout\n");
     if ( w == this )
 	w = mainContainer();
     w = WidgetFactory::containerOfWidget( w );
@@ -2044,7 +2059,7 @@ void FormWindow::breakLayout( QWidget *w )
 	return;
 
     clearSelection( FALSE );
-    MacroCommand *cmd = new MacroCommand( tr( "Break Layout" ), this, commands );
+    MacroCommand *cmd = new MacroCommand( i18n( "Break Layout" ), this, commands );
     commandHistory()->addCommand( cmd );
     cmd->execute();
 }
@@ -2063,7 +2078,7 @@ BreakLayoutCommand *FormWindow::breakLayoutCommand( QWidget *w )
 	     insertedWidgets.find( (QWidget*)o ) )
 	    widgets.append( (QWidget*)o );
     }
-    return new BreakLayoutCommand( tr( "Break Layout" ), this, WidgetFactory::widgetOfContainer( w ), widgets );
+    return new BreakLayoutCommand( i18n( "Break Layout" ), this, WidgetFactory::widgetOfContainer( w ), widgets );
 }
 
 int FormWindow::numVisibleWidgets() const
@@ -2122,7 +2137,7 @@ void FormWindow::editConnections()
 	return;
     mainWindow()->statusBar()->clear();
     ConnectionEditor editor( mainwindow, connectSender, connectReceiver, this );
-    mainWindow()->statusBar()->message( tr( "Edit connections...") );
+    mainWindow()->statusBar()->message( i18n( "Edit connections...") );
     editor.exec();
     mainWindow()->statusBar()->clear();
     if ( !toolFixed )
@@ -2502,6 +2517,28 @@ void FormWindow::setMainContainer( QWidget *w )
 #endif
 }
 
+QMap<QString, QString> FormWindow::scriptObjects() const
+{
+	QMap<QString, QString> objects;
+
+	// get all children of main container with class name ScriptObject
+	const QObjectList *ol = mainContainer()->children();
+	if(ol)
+	{
+		QObjectListIt it(*ol);
+		while(it.current())
+		{
+			if(QString(it.current()->className()) == "ScriptObject")
+			{
+				ScriptObject *sObj = (ScriptObject *)it.current();
+				objects[QString(sObj->name())] = sObj->widgetText();
+			}
+			++it;
+		}
+	}
+	return objects;
+}
+
 bool FormWindow::savePixmapInline() const
 {
     return pixInline;
@@ -2583,12 +2620,14 @@ void FormWindow::killAccels( QObject *top )
     delete l;
 }
 
+#ifndef KOMMANDER
 DesignerFormWindow *FormWindow::iFace()
 {
     if ( !iface )
 	iface = new DesignerFormWindowImpl( this );
     return iface;
 }
+#endif
 
 bool FormWindow::isCentralWidget( QObject *w ) const
 {
