@@ -49,6 +49,7 @@
 #include <qobjectlist.h>
 #include <qmetaobject.h>
 #include <qworkspace.h>
+#include <qtabwidget.h>
 #include <qapplication.h>
 #include <qbuffer.h>
 #include <qlayout.h>
@@ -71,6 +72,8 @@
 #include <qtable.h>
 #endif
 
+#include <klocale.h>
+
 static QString makeIndent( int indent )
 {
     QString s;
@@ -114,7 +117,9 @@ Resource::Resource()
     copying = FALSE;
     pasting = FALSE;
     hadGeometry = FALSE;
+#ifndef KOMMANDER
     langIface = 0;
+#endif
     hasFunctions = FALSE;
 }
 
@@ -126,14 +131,18 @@ Resource::Resource( MainWindow* mw )
     copying = FALSE;
     pasting = FALSE;
     hadGeometry = FALSE;
+#ifndef KOMMANDER
     langIface = 0;
+#endif
     hasFunctions = FALSE;
 }
 
 Resource::~Resource()
 {
+#ifndef KOMMANDER
     if ( langIface )
 	langIface->release();
+#endif
 }
 
 void Resource::setWidget( FormWindow *w )
@@ -163,9 +172,6 @@ bool Resource::load( FormFile *ff )
     return b;
 }
 
-#undef signals
-#undef slots
-
 bool Resource::load( FormFile *ff, QIODevice* dev )
 {
     QDomDocument doc;
@@ -185,15 +191,13 @@ bool Resource::load( FormFile *ff, QIODevice* dev )
     formwindow->setMainWindow( mainwindow );
     MetaDataBase::addEntry( formwindow );
 
-    if (!langIface) {
 #ifndef KOMMANDER
+    if (!langIface) {
 	langIface = MetaDataBase::languageInterface( mainwindow->currProject()->language() );
-#else
-	langIface = MetaDataBase::languageInterface( "C++" );
-#endif
 	if ( langIface )
 	    langIface->addRef();
     }
+#endif
 
     QDomElement e = doc.firstChild().toElement().firstChild().toElement();
 
@@ -209,13 +213,13 @@ bool Resource::load( FormFile *ff, QIODevice* dev )
     while ( variables.tagName() != "variables" && !variables.isNull() )
 	variables = variables.nextSibling().toElement();
 
-    QDomElement signals = e;
-    while ( signals.tagName() != "signals" && !signals.isNull() )
-	signals = signals.nextSibling().toElement();
+    QDomElement eltSignals = e;
+    while ( eltSignals.tagName() != "signals" && !eltSignals.isNull() )
+	eltSignals = eltSignals.nextSibling().toElement();
 
-    QDomElement slots = e;
-    while ( slots.tagName() != "slots" && !slots.isNull() )
-	slots = slots.nextSibling().toElement();
+    QDomElement eltSlots = e;
+    while ( eltSlots.tagName() != "slots" && !eltSlots.isNull() )
+	eltSlots = eltSlots.nextSibling().toElement();
 
     QDomElement connections = e;
     while ( connections.tagName() != "connections" && !connections.isNull() )
@@ -312,7 +316,7 @@ bool Resource::load( FormFile *ff, QIODevice* dev )
     if ( !w )
 	return FALSE;
     if ( previewMode )
-	w->reparent( MainWindow::self, Qt::WType_TopLevel,  w->pos(), TRUE );	
+	w->reparent( MainWindow::self, Qt::WType_TopLevel,  w->pos(), TRUE );
 #else
     if ( !createObject( widget, formwindow) )
 	return FALSE;
@@ -347,13 +351,13 @@ bool Resource::load( FormFile *ff, QIODevice* dev )
 	    if ( n.tagName() == "variable" )
 		metaVariables << n.firstChild().toText().data();
     }
-    if ( !signals.isNull() ) {
-	for ( QDomElement n = signals.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() )
+    if ( !eltSignals.isNull() ) {
+	for ( QDomElement n = eltSignals.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() )
 	    if ( n.tagName() == "signal" )
 		metaSignals << n.firstChild().toText().data();
     }
-    if ( !slots.isNull() ) {
-	for ( QDomElement n = slots.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() )
+    if ( !eltSlots.isNull() ) {
+	for ( QDomElement n = eltSlots.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() )
 	    if ( n.tagName() == "slot" ) {
 		MetaDataBase::Slot slot;
 		slot.specifier = n.attribute( "specifier", "virtual" );
@@ -385,22 +389,29 @@ bool Resource::load( FormFile *ff, QIODevice* dev )
 
     if ( !connections.isNull() )
 	loadConnections( connections );
+#ifndef KOMMANDER
     if ( !functions.isNull() )
+
 	loadFunctions( functions );
+#endif
     if ( !tabOrder.isNull() )
 	loadTabOrder( tabOrder );
 
     if ( formwindow ) {
 	MetaDataBase::setIncludes( formwindow, metaIncludes );
 	MetaDataBase::setForwards( formwindow, metaForwards );
-	MetaDataBase::setVariables( formwindow, metaVariables );
+#ifndef KOMMANDER
+    MetaDataBase::setVariables( formwindow, metaVariables );
+#endif
 	MetaDataBase::setSignalList( formwindow, metaSignals );
 	metaInfo.classNameChanged = metaInfo.className != QString( formwindow->name() );
 	MetaDataBase::setMetaInfo( formwindow, metaInfo );
 	MetaDataBase::setExportMacro( formwindow->mainContainer(), exportMacro );
     }
 
+#ifndef KOMMANDER
     loadExtraSource();
+#endif
 
     if ( mainwindow && formwindow )
     {
@@ -425,12 +436,9 @@ bool Resource::save( const QString& filename, bool formCodeOnly )
 {
     if ( !formwindow || filename.isEmpty() )
 	return FALSE;
-    if (!langIface) {
 #ifndef KOMMANDER
+    if (!langIface) {
 	    langIface = MetaDataBase::languageInterface( mainwindow->self->currProject()->language() );
-#else
-	    langIface = MetaDataBase::languageInterface( "C++" );
-#endif
 	if ( langIface )
 	    langIface->addRef();
     }
@@ -438,6 +446,7 @@ bool Resource::save( const QString& filename, bool formCodeOnly )
 	saveFormCode();
 	return TRUE; // missing error checking in saveFormCode ?
     }
+#endif
     currFileName = filename;
 
     QFile f( filename );
@@ -453,15 +462,13 @@ bool Resource::save( QIODevice* dev )
     if ( !formwindow )
 	return FALSE;
 
-    if (!langIface) {
 #ifndef KOMMANDER
+    if (!langIface) {
 	    langIface = MetaDataBase::languageInterface( mainwindow->self->currProject()->language() );
-#else
-	    langIface = MetaDataBase::languageInterface( "C++" );
-#endif
 	if ( langIface )
 	    langIface->addRef();
     }
+#endif
 
     QTextStream ts( dev );
     ts.setCodec( QTextCodec::codecForName( "UTF-8" ) );
@@ -484,7 +491,9 @@ bool Resource::save( QIODevice* dev )
     saveTabOrder( ts, 0 );
     saveMetaInfoAfter( ts, 0 );
     ts << "</UI>" << endl;
+#ifndef KOMMANDER
     saveFormCode();
+#endif
     images.clear();
 
     return TRUE;
@@ -597,13 +606,13 @@ void Resource::paste( const QString &cb, QWidget *parent )
     formwindow->emitShowProperties();
     buf.close();
 
-    PasteCommand *cmd = new PasteCommand( FormWindow::tr( "Paste" ), formwindow, widgets );
+    PasteCommand *cmd = new PasteCommand( i18n( "Paste" ), formwindow, widgets );
     formwindow->commandHistory()->addCommand( cmd );
 }
 
 void Resource::saveObject( QObject *obj, QDesignerGridLayout* grid, QTextStream &ts, int indent )
 {
-    if ( obj && obj->isWidgetType() && ( (QWidget*)obj )->isHidden() )
+    if ( obj && obj->isWidgetType() && ( (QWidget*)obj )->isHidden() && !(obj->isA("ScriptObject")) )
 	return;
     QString closeTag;
     if ( obj->isWidgetType() ) {
@@ -878,7 +887,7 @@ QPixmap Resource::loadPixmap( const QDomElement &e, const QString &/*tagname*/ )
 	pix.convertFromImage( img );
 	MetaDataBase::setPixmapArgument( formwindow, pix.serialNumber(), arg );
 	return pix;
-    } 
+    }
 #ifndef KOMMANDER
     else if ( formwindow && formwindow->savePixmapInProject() ) {
 	QPixmap pix;
@@ -1407,12 +1416,11 @@ QObject *Resource::createObject( const QDomElement &e, QWidget *parent, QLayout*
 	} else if ( n.tagName() == "column" || n.tagName() =="row" ) {
 	    createColumn( n, w );
 	} else if ( n.tagName() == "event" ) {
+	qDebug("Resource : Tag == event");
 #ifndef KOMMANDER
 	    MetaDataBase::setEventFunctions( obj, formwindow, MainWindow::self->currProject()->language(),
-#else
-	    MetaDataBase::setEventFunctions( obj, formwindow, "C++",
-#endif
 					     n.attribute( "name" ), QStringList::split( ',', n.attribute( "functions" ) ), FALSE );
+#endif
 	}
 
 	n = n.nextSibling().toElement();
@@ -1578,6 +1586,7 @@ void Resource::createItem( const QDomElement &e, QWidget *widget, QListViewItem
 			pixmaps << pix;
 		    }
 		}
+
 	    } else if ( n.tagName() == "item" ) {
 		item->setOpen( TRUE );
 		createItem( n, widget, item );
@@ -1942,9 +1951,6 @@ void Resource::saveConnections( QTextStream &ts, int indent )
 
 #ifndef KOMMANDER
     QString lang = formwindow->project()->language();
-#else
-    QString lang = "C++";
-#endif
     LanguageInterface *iface = langIface;
     if ( iface && MetaDataBase::hasEvents( lang ) ) {
 	QObjectList *l = formwindow->queryList( "QWidget" );
@@ -1968,6 +1974,7 @@ void Resource::saveConnections( QTextStream &ts, int indent )
 	}
 	delete l;
     }
+#endif
 
     indent--;
     ts << makeIndent( indent ) << "</connections>" << endl;
@@ -2025,13 +2032,19 @@ void Resource::loadConnections( const QDomElement &e )
 		    conn.receiver = formwindow->mainContainer();
 	    }
 	    if ( conn.sender && conn.receiver ) {
+#ifndef KOMMANDER
 		if ( lang == "C++" ) {
 		    MetaDataBase::addConnection( formwindow ? formwindow : toplevel,
 						 conn.sender, conn.signal, conn.receiver, conn.slot );
-		} else if ( MetaDataBase::hasEvents( lang ) ) {
+		}
+		else if ( MetaDataBase::hasEvents( lang ) ) {
 		    MetaDataBase::setEventFunctions( conn.sender, formwindow, lang, conn.signal,
 						     QStringList::split( ',', conn.slot ), FALSE );
 		}
+#else
+		    MetaDataBase::addConnection( formwindow ? formwindow : toplevel,
+						 conn.sender, conn.signal, conn.receiver, conn.slot );
+#endif
 	    }
 	} else if ( n.tagName() == "slot" ) { // compatibility with 2.x
 	    MetaDataBase::Slot slot;
@@ -2257,8 +2270,6 @@ void Resource::saveMetaInfoAfter( QTextStream &ts, int indent )
     MetaDataBase::MetaInfo info = MetaDataBase::metaInfo( formwindow );
 #ifndef KOMMANDER
     if ( !langIface || formwindow->project()->language() == "C++" ) {
-#else
-    if ( !langIface ) {
 #endif
 	QValueList<MetaDataBase::Include> includes = MetaDataBase::includes( formwindow );
 	QString extensionInclude;
@@ -2273,21 +2284,21 @@ void Resource::saveMetaInfoAfter( QTextStream &ts, int indent )
 	if ( !includes.isEmpty() || needExtensionInclude ) {
 	    ts << makeIndent( indent ) << "<includes>" << endl;
 	    indent++;
-	
+
 	    for ( QValueList<MetaDataBase::Include>::Iterator it = includes.begin(); it != includes.end(); ++it ) {
 		ts << makeIndent( indent ) << "<include location=\"" << (*it).location
 		   << "\" impldecl=\"" << (*it).implDecl << "\">" << (*it).header << "</include>" << endl;
 		if ( needExtensionInclude )
 		    needExtensionInclude = (*it).header != extensionInclude;
 	    }
-	
+
 	    if ( needExtensionInclude )
 		ts << makeIndent( indent ) << "<include location=\"local\" impldecl=\"in implementation\">"
 		   << extensionInclude << "</include>" << endl;
 	    indent--;
 	    ts << makeIndent( indent ) << "</includes>" << endl;
 	}
-	
+
 	QStringList forwards = MetaDataBase::forwards( formwindow );
 	if ( !forwards.isEmpty() ) {
 	    ts << makeIndent( indent ) << "<forwards>" << endl;
@@ -2297,6 +2308,7 @@ void Resource::saveMetaInfoAfter( QTextStream &ts, int indent )
 	    indent--;
 	    ts << makeIndent( indent ) << "</forwards>" << endl;
 	}
+#ifndef KOMMANDER
 	QStringList vars = MetaDataBase::variables( formwindow );
 	if ( !vars.isEmpty() ) {
 	    ts << makeIndent( indent ) << "<variables>" << endl;
@@ -2306,6 +2318,7 @@ void Resource::saveMetaInfoAfter( QTextStream &ts, int indent )
 	    indent--;
 	    ts << makeIndent( indent ) << "</variables>" << endl;
 	}
+#endif
 	QStringList sigs = MetaDataBase::signalList( formwindow );
 	if ( !sigs.isEmpty() ) {
 	    ts << makeIndent( indent ) << "<signals>" << endl;
@@ -2314,15 +2327,13 @@ void Resource::saveMetaInfoAfter( QTextStream &ts, int indent )
 		ts << makeIndent( indent ) << "<signal>" << entitize( *it3 ) << "</signal>" << endl;
 	    indent--;
 	    ts << makeIndent( indent ) << "</signals>" << endl;
-	}
+
 	QValueList<MetaDataBase::Slot> slotList = MetaDataBase::slotList( formwindow );
 	if ( !slotList.isEmpty() ) {
 	    ts << makeIndent( indent ) << "<slots>" << endl;
 	    indent++;
 #ifndef KOMMANDER
 	    QString lang = formwindow->project()->language();
-#else
-	    QString lang = "C++";
 #endif
 	    QValueList<MetaDataBase::Slot>::Iterator it = slotList.begin();
 	    for ( ; it != slotList.end(); ++it ) {
@@ -2452,13 +2463,12 @@ void Resource::loadChildAction( QObject *parent, const QDomElement &e )
 	    if ( n2.tagName() == "property" ) {
 		setObjectProperty( a, n2.attribute( "name" ), n2.firstChild().toElement() );
 	    } else if ( n2.tagName() == "event" ) {
+	    	qDebug("Resource::loadChildAction : Tag == Event");
 #ifndef KOMMANDER
 		MetaDataBase::setEventFunctions( a, formwindow, MainWindow::self->currProject()->language(),
-#else
-		MetaDataBase::setEventFunctions( a, formwindow, "C++",
-#endif
 						 n2.attribute( "name" ),
 						 QStringList::split( ',', n2.attribute( "functions" ) ), FALSE );
+#endif
 	    }
 	    n2 = n2.nextSibling().toElement();
 	}
@@ -2475,13 +2485,12 @@ void Resource::loadChildAction( QObject *parent, const QDomElement &e )
 			n2.tagName() == "actiongroup" ) {
 		loadChildAction( a, n2 );
 	    } else if ( n2.tagName() == "event" ) {
+	    	qDebug("Resource::loadChildAction : Tag == Event");
 #ifndef KOMMANDER
 		MetaDataBase::setEventFunctions( a, formwindow, MainWindow::self->currProject()->language(),
-#else
-		MetaDataBase::setEventFunctions( a, formwindow, "C++",
-#endif
 						 n2.attribute( "name" ),
 						 QStringList::split( ',', n2.attribute( "functions" ) ), FALSE );
+#endif
 	    }
 	    n2 = n2.nextSibling().toElement();
 	}
@@ -2648,6 +2657,7 @@ void Resource::loadMenuBar( const QDomElement &e )
     }
 }
 
+#ifndef KOMMANDER
 void Resource::saveFormCode()
 {
 #ifndef KOMMANDER
@@ -2705,6 +2715,7 @@ void Resource::saveFormCode()
 			     MetaDataBase::variables( formwindow ), conns );
     }
 }
+#endif
 
  // compatibility with early 3.0 betas
 
@@ -2723,6 +2734,7 @@ static QString make_function_pretty( const QString &s )
     return res;
 }
 
+#ifndef KOMMANDER
 void Resource::loadFunctions( const QDomElement &e )
 {
     QDomElement n = e.firstChild().toElement();
@@ -2768,7 +2780,7 @@ void Resource::loadFunctions( const QDomElement &e )
 	    hasFunctions = TRUE;
 	}
     }
-	
+
 }
 
 void Resource::loadExtraSource()
@@ -2866,3 +2878,4 @@ void Resource::loadExtraSource()
     }
     MetaDataBase::setIncludes( formwindow, incls );
 }
+#endif
