@@ -25,7 +25,7 @@
 #include "widgetdatabase.h"
 
 #include <qapplication.h>
-#define NO_STATIC_COLORS
+//#define NO_STATIC_COLORS
 #include "globaldefs.h"
 #include <qstrlist.h>
 #include <qdict.h>
@@ -40,7 +40,7 @@
 const int dbsize = 300;
 const int dbcustom = 200;
 const int dbdictsize = 211;
-static WidgetDatabaseRecord* db[ dbsize ];
+static WidgetDatabaseRecord* widget_db[ dbsize ];
 static QDict<int> *className2Id = 0;
 static int dbcount  = 0;
 static int dbcustomcount = 200;
@@ -567,7 +567,7 @@ void WidgetDatabase::setupDataBase( int id )
     r->isContainer = TRUE;
 
     append( r );
-	
+
     r = new WidgetDatabaseRecord;
     r->name = "EditorTabWidget";
     r->group = widgetGroup( "Temp" );
@@ -624,7 +624,7 @@ void WidgetDatabase::setupDataBase( int id )
 	r->iconSet = "lineedit.xpm";
     //r->includeFile = "fileselector.h";
     r->group = widgetGroup( "Kommander" );
-    r->toolTip = "A widget made up of a line edit and push button, for selecting files and directories";
+    r->toolTip = "A widget made up of a line edit and push button, for selecting files and folders";
 //    r->isContainer = FALSE;
 
     append( r );
@@ -699,6 +699,33 @@ void WidgetDatabase::setupDataBase( int id )
 //    r->isContainer = FALSE;
 
     append( r );
+
+    r = new WidgetDatabaseRecord;
+    r->iconSet = "";
+    r->name = "ScriptObject";
+//    r->group = widgetGroup( "Kommander" );
+ //   r->toolTip = "";
+//    r->isContainer = FALSE;
+
+    append( r );
+
+    r = new WidgetDatabaseRecord;
+    r->name = "RichTextEditor";
+	r->iconSet = "textedit.xpm";
+    r->group = widgetGroup( "Kommander" );
+    r->toolTip = "A small rich text editor";
+
+ 	append( r );
+
+    r = new WidgetDatabaseRecord;
+    r->name = "TreeWidget";
+	r->iconSet = "listview.xpm";
+    r->group = widgetGroup( "Kommander" );
+    r->toolTip = "A tree widget";
+
+    append( r );
+
+
 #endif
 
 #ifndef UIC
@@ -916,9 +943,9 @@ WidgetDatabaseRecord *WidgetDatabase::at( int index )
     if ( index < 0 )
 	return 0;
     if ( index >= dbcustom && index < dbcustomcount )
-	return db[ index ];
+	return widget_db[ index ];
     if ( index < dbcount )
-	return db[ index ];
+	return widget_db[ index ];
     return 0;
 }
 
@@ -926,7 +953,7 @@ void WidgetDatabase::insert( int index, WidgetDatabaseRecord *r )
 {
     if ( index < 0 || index >= dbsize )
 	return;
-    db[ index ] = r;
+    widget_db[ index ] = r;
     className2Id->insert( r->name, new int( index ) );
     if ( index < dbcustom )
 	dbcount = QMAX( dbcount, index );
@@ -950,7 +977,7 @@ bool WidgetDatabase::isGroupEmpty( const QString &grp )
 {
     WidgetDatabaseRecord *r = 0;
     for ( int i = 0; i < dbcount; ++i ) {
-	if ( !( r = db[ i ] ) )
+	if ( !( r = widget_db[ i ] ) )
 	    continue;
 	if ( r->group == grp )
 	{
@@ -958,7 +985,7 @@ bool WidgetDatabase::isGroupEmpty( const QString &grp )
 	    if(r->group == "Kommander")
 		    return FALSE;
 
-	    if(r->name[0] != 'Q') 
+	    if(r->name[0] != 'Q')
   	        return FALSE;
 	}
     }
