@@ -18,11 +18,14 @@
 **
 **********************************************************************/
 
+#include <klocale.h>
+
 #include <qvariant.h> // HP-UX compiler need this here
 #include "widgetfactory.h"
 #include "widgetdatabase.h"
 #include "metadatabase.h"
 #include "mainwindow.h"
+#include "formwindow.h"
 #include "pixmapchooser.h"
 #include "layout.h"
 #include "listboxeditorimpl.h"
@@ -30,8 +33,6 @@
 #include "iconvieweditorimpl.h"
 #include "multilineeditorimpl.h"
 #include "widgetinterface.h"
-#include "command.h"
-#include "formwindow.h"
 #ifndef QT_NO_TABLE
 #include "tableeditorimpl.h"
 #endif
@@ -47,7 +48,6 @@
 #ifndef QT_NO_SQL
 #include <qdatatable.h>
 #endif
-#include <qwidgetstack.h>
 #include <qdatetimeedit.h>
 #include <qlineedit.h>
 #include <qspinbox.h>
@@ -55,6 +55,7 @@
 #include <qtextedit.h>
 #include <qlabel.h>
 #include <qlayout.h>
+#include <qwidgetstack.h>
 #include <qcombobox.h>
 #include <qtabbar.h>
 #include <qlistbox.h>
@@ -80,7 +81,7 @@
 #include "database.h"
 #endif
 
-#define NO_STATIC_COLORS
+//#define NO_STATIC_COLORS
 #include "globaldefs.h"
 
 /* KOMMANDER INCLUDES */
@@ -101,7 +102,10 @@
 #include <tabwidget.h>
 #include <subdialog.h>
 #include <listbox.h>
-#include <qwidgetstack.h>
+#include <scriptobject.h>
+#include <richtexteditor.h>
+#include <treewidget.h>
+
 
 
 FormWindow *find_formwindow( QWidget *w )
@@ -276,7 +280,7 @@ bool QDesignerTabWidget::eventFilter( QObject *o, QEvent *e )
 
 		FormWindow *fw = find_formwindow( this );
 		MoveTabPageCommand *cmd =
-		    new MoveTabPageCommand( tr( "Move Tab Page" ), fw, this,
+		    new MoveTabPageCommand( i18n( "Move Tab Page" ), fw, this,
 					    dragPage, dragLabel, newIndex, oldIndex );
 		fw->commandHistory()->addCommand( cmd );
 		cmd->execute();
@@ -556,7 +560,7 @@ bool EditorTabWidget::eventFilter( QObject *o, QEvent *e )
 
 		FormWindow *fw = find_formwindow( this );
 		MoveTabPageCommand *cmd =
-		    new MoveTabPageCommand( tr( "Move Tab Page" ), fw, this,
+		    new MoveTabPageCommand( i18n( "Move Tab Page" ), fw, this,
 					    dragPage, dragLabel, newIndex, oldIndex );
 		fw->commandHistory()->addCommand( cmd );
 		cmd->execute();
@@ -890,7 +894,7 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
 #if !defined(QT_NO_ICONVIEW)
 	QIconView* iv = new QIconView( parent, name );
 	if ( init )
-	    (void) new QIconViewItem( iv, MainWindow::tr( "New Item" ) );
+	    (void) new QIconViewItem( iv, i18n( "New Item" ) );
 	return iv;
 #else
 	return 0;
@@ -917,7 +921,7 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
     else if ( className == "QListBox" ) {
 	QListBox* lb = new QListBox( parent, name );
 	if ( init ) {
-	    lb->insertItem( MainWindow::tr( "New Item" ) );
+	    lb->insertItem( i18n( "New Item" ) );
 	    lb->setCurrentItem( 0 );
 	}
 	return lb;
@@ -925,8 +929,8 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
 	QListView *lv = new QListView( parent, name );
 	lv->setSorting( -1 );
 	if ( init ) {
-	    lv->addColumn( MainWindow::tr( "Column 1" ) );
-	    lv->setCurrentItem( new QListViewItem( lv, MainWindow::tr( "New Item" ) ) );
+	    lv->addColumn( i18n( "Column 1" ) );
+	    lv->setCurrentItem( new QListViewItem( lv, i18n( "New Item" ) ) );
 	}
 	return lv;
     } else if ( className == "QLineEdit" )
@@ -964,10 +968,10 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
 	if ( init ) {
 	    FormWindow *fw = find_formwindow( parent );
 	    QWidget *w = fw ? new QDesignerWidget( fw, tw, "tab" ) : new QWidget( tw, "tab" );
-	    tw->addTab( w, MainWindow::tr("Tab 1") );
+	    tw->addTab( w, i18n("Tab 1") );
 	    MetaDataBase::addEntry( w );
 	    w = fw ? new QDesignerWidget( fw, tw, "tab" ) : new QWidget( tw, "tab" );
-	    tw->addTab( w, MainWindow::tr("Tab 2") );
+	    tw->addTab( w, i18n("Tab 2") );
 	    MetaDataBase::addEntry( tw );
 	    MetaDataBase::addEntry( w );
 	}
@@ -1010,7 +1014,7 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
 	if ( init && parent && parent->inherits( "FormWindow" ) ) {
 	    QDesignerWidget *dw = new QDesignerWidget( (FormWindow*)parent, wiz, "page" );
 	    MetaDataBase::addEntry( dw );
-	    wiz->addPage( dw, FormWindow::tr( "Page" ) );
+	    wiz->addPage( dw, i18n( "Page" ) );
 	    QTimer::singleShot( 0, wiz, SLOT( next() ) );
 	}
 	return wiz;
@@ -1113,8 +1117,8 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
 		lv->setSorting( -1 );
 		if ( init )
 		{
-			lv->addColumn( MainWindow::tr( "Column 1" ) );
-			lv->setCurrentItem( new QListViewItem( lv, MainWindow::tr( "New Item" ) ) );
+			lv->addColumn( i18n( "Column 1" ) );
+			lv->setCurrentItem( new QListViewItem( lv, i18n( "New Item" ) ) );
 		}
 		return lv;
 	}
@@ -1138,7 +1142,7 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
 		if ( init && parent && parent->inherits( "FormWindow" ) ) {
 			QDesignerWidget *dw = new QDesignerWidget( (FormWindow*)parent, wiz, "page" );
 			MetaDataBase::addEntry( dw );
-			wiz->addPage( dw, FormWindow::tr( "Page" ) );
+			wiz->addPage( dw, i18n( "Page" ) );
 			QTimer::singleShot( 0, wiz, SLOT( next() ) );
 		}
 		return wiz;
@@ -1150,10 +1154,10 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
 		{
 			FormWindow *fw = find_formwindow( parent );
 			QWidget *w = fw ? new QDesignerWidget( fw, tw, "tab" ) : new QWidget( tw, "tab" );
-			tw->addTab( w, MainWindow::tr("Tab 1") );
+			tw->addTab( w, i18n("Tab 1") );
 			MetaDataBase::addEntry( w );
 			w = fw ? new QDesignerWidget( fw, tw, "tab" ) : new QWidget( tw, "tab" );
-			tw->addTab( w, MainWindow::tr("Tab 2") );
+			tw->addTab( w, i18n("Tab 2") );
 			MetaDataBase::addEntry( tw );
 			MetaDataBase::addEntry( w );
 		}
@@ -1183,6 +1187,20 @@ QWidget *WidgetFactory::createWidget( const QString &className, QWidget *parent,
 		return new SpinBoxInt(parent, name);
 	else if(className == "ListBox")
 		return new ListBox(parent, name);
+	else if(className == "ScriptObject")
+		return new ScriptObject(parent, name);
+	else if(className == "RichTextEditor")
+		return new RichTextEditor(parent, name);
+	else if(className == "TreeWidget")
+	{
+	    QListView *lv = new TreeWidget( parent, name );
+	    lv->setSorting( -1 );
+	    if ( init ) {
+		lv->addColumn( i18n( "Column 1" ) );
+		lv->setCurrentItem( new QListViewItem( lv, i18n( "New Item" ) ) );
+	    }
+	    return lv;
+	}
 #endif
 
     WidgetInterface *iface = 0;
@@ -1443,7 +1461,7 @@ bool WidgetFactory::hasSpecialEditor( int id )
     QString className = WidgetDatabase::className( id );
 
 #ifdef KOMMANDER
-    if(className == "TextEdit" || className == "ComboBox")
+    if(className == "TextEdit" || className == "ComboBox" || className == "TreeWidget")
 	    return TRUE;
 #endif
     if ( className.mid( 1 ) == "ListBox" )
@@ -1467,7 +1485,7 @@ bool WidgetFactory::hasItems( int id )
     QString className = WidgetDatabase::className( id );
 
 #ifdef KOMMANDER
-    if(className == "ComboBox")
+    if(className == "ComboBox" || className == "ListBox" || className == "TreeWidget")
 	    return TRUE;
 #endif
     if ( className.mid( 1 ) == "ListBox" || className.mid( 1 ) == "ListView" ||
@@ -1505,6 +1523,16 @@ void WidgetFactory::editWidget( int id, QWidget *parent, QWidget *editWidget, Fo
 		delete e;
 		return;
 	}
+	if(className == "TreeWidget")
+	{
+	    if ( !editWidget->inherits( "QListView" ) )
+		return;
+	    QListView *lv = (QListView*)editWidget;
+	    ListViewEditor *e = new ListViewEditor( parent, lv, fw );
+	    e->exec();
+	    delete e;
+	    return;
+	}
 #endif
     if ( className.mid( 1 ) == "ListBox" )
     {
