@@ -19,6 +19,7 @@
 **********************************************************************/
 
 #include <qvariant.h>  // HP-UX compiler needs this here
+#include <qlistview.h>
 #include "workspace.h"
 #include "formwindow.h"
 #include "mainwindow.h"
@@ -28,13 +29,12 @@
 #ifndef KOMMANDER
 #include "project.h"
 #include "pixmapcollection.h"
-#endif
 #include "sourcefile.h"
 #include "sourceeditor.h"
+#endif
 #include "formfile.h"
 
 #include <qheader.h>
-#include <qdragobject.h>
 #include <qfileinfo.h>
 #include <qapplication.h>
 #include <qpainter.h>
@@ -45,7 +45,10 @@
 #include <qtextstream.h>
 #include "qcompletionedit.h"
 
-static const char * const folder_xpm[]={
+#include <kurldrag.h>
+#include <klocale.h>
+
+static const char * const folderxpm[]={
     "16 16 6 1",
     ". c None",
     "b c #ffff00",
@@ -114,6 +117,7 @@ WorkspaceItem::WorkspaceItem( QListView *parent )
     setExpandable( FALSE );
 }
 
+#ifndef KOMMANDER
 WorkspaceItem::WorkspaceItem( QListViewItem *parent, SourceFile* sf )
     : QListViewItem( parent )
 {
@@ -122,6 +126,7 @@ WorkspaceItem::WorkspaceItem( QListViewItem *parent, SourceFile* sf )
     t = SourceFileType;
     setPixmap( 0, *filePixmap );
 }
+#endif
 
 WorkspaceItem::WorkspaceItem( QListViewItem *parent, FormFile* ff, Type type )
     : QListViewItem( parent )
@@ -130,16 +135,17 @@ WorkspaceItem::WorkspaceItem( QListViewItem *parent, FormFile* ff, Type type )
     formFile = ff;
     t = type;
     if ( type ==  FormFileType ) {
-	setPixmap( 0, *formPixmap );
-	QObject::connect( ff, SIGNAL( somethingChanged(FormFile*) ), listView(), SLOT( update(FormFile*) ) );
-	if ( formFile->supportsCodeFile() )
-	    (void) new WorkspaceItem( this, formFile, FormSourceType );
+  setPixmap( 0, *formPixmap );
+  QObject::connect( ff, SIGNAL( somethingChanged(FormFile*) ), listView(), SLOT( update(FormFile*) ) );
+#ifndef KOMMANDER
+  if ( formFile->supportsCodeFile() )
+      (void) new WorkspaceItem( this, formFile, FormSourceType );
     } else if ( type == FormSourceType ) {
-	setPixmap( 0, *filePixmap );
+  setPixmap( 0, *filePixmap );
+#endif
     }
 }
 
-#ifdef KOMMANDER
 WorkspaceItem::WorkspaceItem( QListView *parent, FormFile* ff, Type type )
     : QListViewItem( parent )
 {
@@ -147,15 +153,16 @@ WorkspaceItem::WorkspaceItem( QListView *parent, FormFile* ff, Type type )
     formFile = ff;
     t = type;
     if ( type ==  FormFileType ) {
-	setPixmap( 0, *formPixmap );
-	QObject::connect( ff, SIGNAL( somethingChanged(FormFile*) ), listView(), SLOT( update(FormFile*) ) );
-	if ( formFile->supportsCodeFile() )
-	    (void) new WorkspaceItem( this, formFile, FormSourceType );
+  setPixmap( 0, *formPixmap );
+  QObject::connect( ff, SIGNAL( somethingChanged(FormFile*) ), listView(), SLOT( update(FormFile*) ) );
+#ifndef KOMMANDER
+  if ( formFile->supportsCodeFile() )
+      (void) new WorkspaceItem( this, formFile, FormSourceType );
     } else if ( type == FormSourceType ) {
-	setPixmap( 0, *filePixmap );
+  setPixmap( 0, *filePixmap );
+#endif
     }
 }
-#endif
 
 
 void WorkspaceItem::init()
@@ -164,8 +171,8 @@ void WorkspaceItem::init()
     useOddColor = FALSE;
 #ifndef KOMMANDER
     project = 0;
-#endif
     sourceFile = 0;
+#endif
     formFile = 0;
 }
 
@@ -175,29 +182,33 @@ void WorkspaceItem::paintCell( QPainter *p, const QColorGroup &cg, int column, i
     g.setColor( QColorGroup::Base, backgroundColor() );
     g.setColor( QColorGroup::Foreground, Qt::black );
 
+#ifndef KOMMANDER
     if ( type() == FormSourceType && !formFile->hasFormCode() ) {
-	g.setColor( QColorGroup::Text, listView()->palette().disabled().color( QColorGroup::Text) );
-	g.setColor( QColorGroup::HighlightedText, listView()->palette().disabled().color( QColorGroup::Text) );
+  g.setColor( QColorGroup::Text, listView()->palette().disabled().color( QColorGroup::Text) );
+  g.setColor( QColorGroup::HighlightedText, listView()->palette().disabled().color( QColorGroup::Text) );
     } else {
-	g.setColor( QColorGroup::Text, Qt::black );
+#endif
+  g.setColor( QColorGroup::Text, Qt::black );
+#ifndef KOMMANDER
     }
+#endif
     p->save();
 
     if ( isModified() ) {
-	QFont f = p->font();
-	f.setBold( TRUE );
-	p->setFont( f );
+  QFont f = p->font();
+  f.setBold( TRUE );
+  p->setFont( f );
     }
 
     QListViewItem::paintCell( p, g, column, width, align );
     p->setPen( QPen( cg.dark(), 1 ) );
     if ( column == 0 )
-	p->drawLine( 0, 0, 0, height() - 1 );
+  p->drawLine( 0, 0, 0, height() - 1 );
     if ( listView()->firstChild() != this ) {
-	if ( nextSibling() != itemBelow() && itemBelow()->depth() < depth() ) {
-	    int d = depth() - itemBelow()->depth();
-	    p->drawLine( -listView()->treeStepSize() * d, height() - 1, 0, height() - 1 );
-	}
+  if ( nextSibling() != itemBelow() && itemBelow()->depth() < depth() ) {
+      int d = depth() - itemBelow()->depth();
+      p->drawLine( -listView()->treeStepSize() * d, height() - 1, 0, height() - 1 );
+  }
     }
     p->drawLine( 0, height() - 1, width, height() - 1 );
     p->drawLine( width - 1, 0, width - 1, height() );
@@ -207,20 +218,22 @@ void WorkspaceItem::paintCell( QPainter *p, const QColorGroup &cg, int column, i
 QString WorkspaceItem::text( int column ) const
 {
     if ( column != 0 )
-	return QListViewItem::text( column );
+  return QListViewItem::text( column );
     switch( t ) {
 #ifndef KOMMANDER
     case ProjectType:
-	if ( project->isDummy() )
-	    return Project::tr("<No Project>" );
-	return project->makeRelative( project->fileName() );
+  if ( project->isDummy() )
+      return Project::i18n("<No Project>" );
+  return project->makeRelative( project->fileName() );
 #endif
     case FormFileType:
-	return formFile->formName() + ": " + formFile->fileName();
+  return formFile->formName() + ": " + formFile->fileName();
+#ifndef KOMMANDER
     case FormSourceType:
-	return formFile->codeFile();
+  return formFile->codeFile();
     case SourceFileType:
-	return sourceFile->fileName();
+  return sourceFile->fileName();
+#endif
     }
 
     return QString::null; // shut up compiler
@@ -230,17 +243,19 @@ void WorkspaceItem::fillCompletionList( QStringList& completion )
 {
     switch( t ) {
     case ProjectType:
-	break;
+  break;
     case FormFileType:
-	completion += formFile->formName();
-	completion += formFile->fileName();
-	break;
+  completion += formFile->formName();
+  completion += formFile->fileName();
+  break;
+#ifndef KOMMANDER
     case FormSourceType:
-	completion += formFile->codeFile();
-	break;
+  completion += formFile->codeFile();
+  break;
     case SourceFileType:
-	completion += sourceFile->fileName();
-	break;
+  completion += sourceFile->fileName();
+  break;
+#endif
     }
 }
 
@@ -248,14 +263,16 @@ bool WorkspaceItem::checkCompletion( const QString& completion )
 {
     switch( t ) {
     case ProjectType:
-	break;
+  break;
     case FormFileType:
-	return  completion == formFile->formName()
-		 || completion == formFile->fileName();
+  return  completion == formFile->formName()
+     || completion == formFile->fileName();
+#ifndef KOMMANDER
     case FormSourceType:
-	return completion == formFile->codeFile();
+  return completion == formFile->codeFile();
     case SourceFileType:
-	return completion == sourceFile->fileName();
+  return completion == sourceFile->fileName();
+#endif
     }
     return FALSE;
 }
@@ -263,28 +280,30 @@ bool WorkspaceItem::checkCompletion( const QString& completion )
 
 bool WorkspaceItem::isModified() const
 {
+#ifndef KOMMANDER
     switch( t ) {
     case ProjectType:
-#ifndef KOMMANDER
-	    return project->isModified();
-#endif
+      return project->isModified();
     case FormFileType:
-	return formFile->isModified( FormFile::WFormWindow );
+  return formFile->isModified( FormFile::WFormWindow );
     case FormSourceType:
-	return formFile->isModified( FormFile::WFormCode );
+  return formFile->isModified( FormFile::WFormCode );
     case SourceFileType:
-	return sourceFile->isModified();
+  return sourceFile->isModified();
     }
     return FALSE; // shut up compiler
+#else
+    return formFile->isModified();
+#endif
 }
 
 QString WorkspaceItem::key( int column, bool ) const
 {
     QString key = text( column );
     if ( t == FormFileType )
-	key.prepend( "0" );
+  key.prepend( "0" );
     else
-	key.prepend( "a" );
+  key.prepend( "a" );
     return key;
 }
 
@@ -292,7 +311,7 @@ QColor WorkspaceItem::backgroundColor()
 {
     bool b = useOddColor;
     if ( t == FormSourceType && parent() )
-	b = ( ( WorkspaceItem*)parent() )->useOddColor;
+  b = ( ( WorkspaceItem*)parent() )->useOddColor;
     return b ? *backColor2 : *backColor1;
 }
 
@@ -311,11 +330,11 @@ void WorkspaceItem::setAutoOpen( bool b )
 
 Workspace::Workspace( QWidget *parent, MainWindow *mw )
     : QListView( parent, 0, WStyle_Customize | WStyle_NormalBorder | WStyle_Title |
-		 WStyle_Tool | WStyle_MinMax | WStyle_SysMenu ), mainWindow( mw ),
+     WStyle_Tool | WStyle_MinMax | WStyle_SysMenu ), mainWindow( mw ),
 #ifndef KOMMANDER
-	project( 0 ), completionDirty( FALSE )
+  project( 0 ), completionDirty( FALSE )
 #else
-	completionDirty( FALSE )
+  completionDirty( FALSE )
 #endif
 {
     init_colors();
@@ -334,14 +353,14 @@ Workspace::Workspace( QWidget *parent, MainWindow *mw )
     p.setColor( QColorGroup::Base, QColor( *backColor2 ) );
     (void)*selectedBack; // hack
     setPalette( p );
-    addColumn( tr( "Files" ) );
+    addColumn( i18n( "Files" ) );
     setAllColumnsShowFocus( TRUE );
     connect( this, SIGNAL( mouseButtonClicked( int, QListViewItem *, const QPoint &, int ) ),
-	     this, SLOT( itemClicked( int, QListViewItem *, const QPoint& ) ) ),
+       this, SLOT( itemClicked( int, QListViewItem *, const QPoint& ) ) ),
     connect( this, SIGNAL( doubleClicked( QListViewItem * ) ),
-	     this, SLOT( itemDoubleClicked( QListViewItem * ) ) ),
+       this, SLOT( itemDoubleClicked( QListViewItem * ) ) ),
     connect( this, SIGNAL( contextMenuRequested( QListViewItem *, const QPoint &, int ) ),
-	     this, SLOT( rmbClicked( QListViewItem *, const QPoint& ) ) ),
+       this, SLOT( rmbClicked( QListViewItem *, const QPoint& ) ) ),
     setHScrollBarMode( AlwaysOff );
     setVScrollBarMode( AlwaysOn );
     viewport()->setAcceptDrops( TRUE );
@@ -349,13 +368,13 @@ Workspace::Workspace( QWidget *parent, MainWindow *mw )
     setColumnWidthMode( 1, Manual );
 
     if ( !folderPixmap ) {
-	folderPixmap = new QPixmap( folder_xpm );
-	filePixmap = new QPixmap( file_xpm );
-	formPixmap = new QPixmap( PixmapChooser::loadPixmap( "form.xpm", PixmapChooser::Mini ) );
+  folderPixmap = new QPixmap( folderxpm );
+  filePixmap = new QPixmap( file_xpm );
+  formPixmap = new QPixmap( PixmapChooser::loadPixmap( "form.xpm", PixmapChooser::Mini ) );
     }
 
 #ifdef KOMMANDER
-	makeConnections(mw);
+  makeConnections(mw);
 #endif
 }
 
@@ -364,8 +383,8 @@ Workspace::Workspace( QWidget *parent, MainWindow *mw )
 void Workspace::projectDestroyed( QObject* o )
 {
     if ( o == project ) {
-	project = 0;
-	clear();
+  project = 0;
+  clear();
     }
 }
 #endif
@@ -374,13 +393,13 @@ void Workspace::projectDestroyed( QObject* o )
 void Workspace::setCurrentProject( Project *pro )
 {
     if ( project == pro )
-	return;
+  return;
     if ( project ) {
-	disconnect( project, SIGNAL( sourceFileAdded(SourceFile*) ), this, SLOT( sourceFileAdded(SourceFile*) ) );
-	disconnect( project, SIGNAL( sourceFileRemoved(SourceFile*) ), this, SLOT( sourceFileRemoved(SourceFile*) ) );
-	disconnect( project, SIGNAL( formFileAdded(FormFile*) ), this, SLOT( formFileAdded(FormFile*) ) );
-	disconnect( project, SIGNAL( formFileRemoved(FormFile*) ), this, SLOT( formFileRemoved(FormFile*) ) );
-	disconnect( project, SIGNAL( projectModified() ), this, SLOT( update() ) );
+  disconnect( project, SIGNAL( sourceFileAdded(SourceFile*) ), this, SLOT( sourceFileAdded(SourceFile*) ) );
+  disconnect( project, SIGNAL( sourceFileRemoved(SourceFile*) ), this, SLOT( sourceFileRemoved(SourceFile*) ) );
+  disconnect( project, SIGNAL( formFileAdded(FormFile*) ), this, SLOT( formFileAdded(FormFile*) ) );
+  disconnect( project, SIGNAL( formFileRemoved(FormFile*) ), this, SLOT( formFileRemoved(FormFile*) ) );
+  disconnect( project, SIGNAL( projectModified() ), this, SLOT( update() ) );
     }
     project = pro;
     connect( project, SIGNAL( sourceFileAdded(SourceFile*) ), this, SLOT( sourceFileAdded(SourceFile*) ) );
@@ -392,22 +411,22 @@ void Workspace::setCurrentProject( Project *pro )
     clear();
 
     if ( bufferEdit )
-	bufferEdit->clear();
+  bufferEdit->clear();
 
     projectItem = new WorkspaceItem( this, project );
 
     projectItem->setOpen( TRUE );
 
     for ( QPtrListIterator<SourceFile> sources = project->sourceFiles();
-	  sources.current(); ++sources ) {
-	SourceFile* f = sources.current();
-	(void) new WorkspaceItem( projectItem, f );
+    sources.current(); ++sources ) {
+  SourceFile* f = sources.current();
+  (void) new WorkspaceItem( projectItem, f );
     }
 
     for ( QPtrListIterator<FormFile> forms = project->formFiles();
-	  forms.current(); ++forms ) {
-	FormFile* f = forms.current();
-	(void) new WorkspaceItem( projectItem, f );
+    forms.current(); ++forms ) {
+  FormFile* f = forms.current();
+  (void) new WorkspaceItem( projectItem, f );
     }
 
     updateColors();
@@ -418,30 +437,33 @@ void Workspace::setCurrentProject( Project *pro )
 #ifdef KOMMANDER
 void Workspace::makeConnections(MainWindow *)
 {
-		// FIXME
+    // FIXME
 }
 #endif
 
+#ifndef KOMMANDER
 void Workspace::sourceFileAdded( SourceFile* sf )
 {
-#ifndef KOMMANDER
     (void) new WorkspaceItem( projectItem, sf );
-#endif
+    Q_UNUSED(sf);
     updateColors();
 }
+#endif
 
+#ifndef KOMMANDER
 void Workspace::sourceFileRemoved( SourceFile* sf )
 {
     delete findItem( sf );
     updateColors();
 }
+#endif
 
 void Workspace::formFileAdded( FormFile* ff )
 {
 #ifndef KOMMANDER
-	(void) new WorkspaceItem( projectItem, ff );
+  (void) new WorkspaceItem( projectItem, ff );
 #else
-	(void) new WorkspaceItem( this, ff );
+  (void) new WorkspaceItem( this, ff );
 #endif
     updateColors();
 }
@@ -463,9 +485,9 @@ void Workspace::update( FormFile* ff )
 {
     QListViewItem* i = findItem( ff );
     if ( i ) {
-	i->repaint();
-	if ( (i = i->firstChild()) )
-	    i->repaint();
+  i->repaint();
+  if ( (i = i->firstChild()) )
+      i->repaint();
     }
 }
 
@@ -474,72 +496,76 @@ void Workspace::activeFormChanged( FormWindow *fw )
 {
     WorkspaceItem *i = findItem( fw->formFile() );
     if ( i ) {
-	setCurrentItem( i );
-	setSelected( i, TRUE );
-	if ( !i->isOpen() )
-	    i->setAutoOpen( TRUE );
+  setCurrentItem( i );
+  setSelected( i, TRUE );
+  if ( !i->isOpen() )
+      i->setAutoOpen( TRUE );
     }
 
     closeAutoOpenItems();
 
 }
 
+#ifndef KOMMANDER
 void Workspace::activeEditorChanged( SourceEditor *se )
 {
     if ( !se->object() )
-	return;
+  return;
 
     if ( se->formWindow() ) {
-	WorkspaceItem *i = findItem( se->formWindow()->formFile() );
-	if ( i && i->firstChild() ) {
-	    if ( !i->isOpen() )
-		i->setAutoOpen( TRUE );
-	    setCurrentItem( i->firstChild() );
-	    setSelected( i->firstChild(), TRUE );
-	}
+  WorkspaceItem *i = findItem( se->formWindow()->formFile() );
+  if ( i && i->firstChild() ) {
+      if ( !i->isOpen() )
+    i->setAutoOpen( TRUE );
+      setCurrentItem( i->firstChild() );
+      setSelected( i->firstChild(), TRUE );
+  }
     } else {
-	WorkspaceItem *i = findItem( se->sourceFile() );
-	if ( i ) {
-	    setCurrentItem( i );
-	    setSelected( i, TRUE );
-	}
+  WorkspaceItem *i = findItem( se->sourceFile() );
+  if ( i ) {
+      setCurrentItem( i );
+      setSelected( i, TRUE );
+  }
     }
 
     closeAutoOpenItems();
 }
+#endif
 
 WorkspaceItem *Workspace::findItem( FormFile* ff)
 {
     QListViewItemIterator it( this );
     for ( ; it.current(); ++it ) {
-	if ( ( (WorkspaceItem*)it.current() )->formFile == ff )
-	    return (WorkspaceItem*)it.current();
+  if ( ( (WorkspaceItem*)it.current() )->formFile == ff )
+      return (WorkspaceItem*)it.current();
     }
     return 0;
 }
 
+#ifndef KOMMANDER
 WorkspaceItem *Workspace::findItem( SourceFile *sf )
 {
     QListViewItemIterator it( this );
     for ( ; it.current(); ++it ) {
-	if ( ( (WorkspaceItem*)it.current() )->sourceFile == sf )
-	    return (WorkspaceItem*)it.current();
+  if ( ( (WorkspaceItem*)it.current() )->sourceFile == sf )
+      return (WorkspaceItem*)it.current();
     }
     return 0;
 }
+#endif
 
 void Workspace::closeAutoOpenItems()
 {
     QListViewItemIterator it( this );
     for ( ; it.current(); ++it ) {
-	WorkspaceItem* i = (WorkspaceItem*) it.current();
-	WorkspaceItem* ip = (WorkspaceItem*) i->parent();
-	if ( i->type() == WorkspaceItem::FormSourceType ) {
-	    if ( !i->isSelected() && !ip->isSelected()
-		 && ip->isAutoOpen() ) {
-		ip->setAutoOpen( FALSE );
-	    }
-	}
+  WorkspaceItem* i = (WorkspaceItem*) it.current();
+  WorkspaceItem* ip = (WorkspaceItem*) i->parent();
+  if ( i->type() == WorkspaceItem::FormSourceType ) {
+      if ( !i->isSelected() && !ip->isSelected()
+     && ip->isAutoOpen() ) {
+    ip->setAutoOpen( FALSE );
+      }
+  }
     }
 }
 
@@ -552,136 +578,143 @@ void Workspace::closeEvent( QCloseEvent *e )
 void Workspace::itemDoubleClicked( QListViewItem *i )
 {
     if ( ( (WorkspaceItem*)i)->type()== WorkspaceItem::ProjectType )
-	i->setOpen( TRUE );
+  i->setOpen( TRUE );
 }
 
 void Workspace::itemClicked( int button, QListViewItem *i, const QPoint& )
 {
     if ( !i || button != LeftButton )
-	return;
+  return;
 
     closeAutoOpenItems();
 
     WorkspaceItem* wi = (WorkspaceItem*)i;
+#ifndef KOMMANDER
     if ( wi->type() == WorkspaceItem::SourceFileType )
-	mainWindow->editSource( wi->sourceFile );
+  mainWindow->editSource( wi->sourceFile );
     switch( wi->type() ) {
     case WorkspaceItem::ProjectType:
-	break; // ### TODO
+  break; // ### TODO
     case WorkspaceItem::FormFileType:
-	wi->formFile->showFormWindow();
-	break;
+  wi->formFile->showFormWindow();
+  break;
     case WorkspaceItem::FormSourceType:
-	wi->formFile->showEditor();
-	break;
+  wi->formFile->showEditor();
+  break;
     case WorkspaceItem::SourceFileType:
-	mainWindow->editSource( wi->sourceFile );
-	break;
+  mainWindow->editSource( wi->sourceFile );
+  break;
     }
+#else
+    wi->formFile->showFormWindow();
+#endif
 }
 
 void Workspace::contentsDropEvent( QDropEvent *e )
 {
-    if ( !QUriDrag::canDecode( e ) ) {
-	e->ignore();
+    if ( !KURLDrag::canDecode( e ) ) {
+  e->ignore();
     } else {
-	QStringList files;
-	QUriDrag::decodeLocalFiles( e, files );
-	if ( !files.isEmpty() ) {
-	    for ( QStringList::Iterator it = files.begin(); it != files.end(); ++it ) {
-		QString fn = *it;
+  KURL::List files;
+  KURLDrag::decode( e, files );
+  if ( !files.isEmpty() ) {
+      for ( KURL::List::Iterator it = files.begin(); it != files.end(); ++it ) {
+          if (!(*it).isLocalFile())
+             continue;
+
+    QString fn = (*it).path();
 #ifndef KOMMANDER
-		mainWindow->fileOpen( "", "", fn );
+    mainWindow->fileOpen( "", "", fn );
 #else
-		mainWindow->fileOpen("", fn);
+    mainWindow->fileOpen("", fn);
 #endif
-	    }
-	}
+      }
+  }
     }
 }
 
 void Workspace::contentsDragEnterEvent( QDragEnterEvent *e )
 {
-    if ( !QUriDrag::canDecode( e ) )
-	e->ignore();
+    if ( !KURLDrag::canDecode( e ) )
+  e->ignore();
     else
-	e->accept();
+  e->accept();
 }
 
 void Workspace::contentsDragMoveEvent( QDragMoveEvent *e )
 {
-    if ( !QUriDrag::canDecode( e ) )
-	e->ignore();
+    if ( !KURLDrag::canDecode( e ) )
+  e->ignore();
     else
-	e->accept();
+  e->accept();
 }
 
 void Workspace::rmbClicked( QListViewItem *i, const QPoint& pos )
 {
     if ( !i )
-	return;
+  return;
     WorkspaceItem* wi = (WorkspaceItem*)i;
     enum { OPEN_SOURCE, REMOVE_SOURCE, OPEN_FORM, REMOVE_FORM, OPEN_FORM_SOURCE };
     QPopupMenu menu( this );
     switch ( wi->type() ) {
 #ifndef KOMMANDER
     case WorkspaceItem::SourceFileType:
-	menu.insertItem( tr( "&Open source file..." ), OPEN_SOURCE );
-	menu.insertSeparator();
-	menu.insertItem( PixmapChooser::loadPixmap( "editcut" ),
-			 tr( "&Remove source file from project" ), REMOVE_SOURCE );
-	break;
+  menu.insertItem( i18n( "&Open Source File..." ), OPEN_SOURCE );
+  menu.insertSeparator();
+  menu.insertItem( PixmapChooser::loadPixmap( "editcut" ),
+       i18n( "&Remove Source File From Project" ), REMOVE_SOURCE );
+  break;
 #endif
     case WorkspaceItem::FormFileType:
-	menu.insertItem( tr( "&Open form..." ), OPEN_FORM );
-	menu.insertSeparator();
-	menu.insertItem( PixmapChooser::loadPixmap( "editcut" ),
+  menu.insertItem( i18n( "&Open Form..." ), OPEN_FORM );
+  menu.insertSeparator();
+  menu.insertItem( PixmapChooser::loadPixmap( "editcut" ),
 #ifndef KOMMANDER
-			 tr( "&Remove form from project" ), REMOVE_FORM );
+       i18n( "&Remove Form From Project" ), REMOVE_FORM );
 #else
-			 tr( "&Remove form" ), REMOVE_FORM );
+       i18n( "&Remove Form" ), REMOVE_FORM );
 #endif
-	break;
+  break;
     case WorkspaceItem::FormSourceType:
-	menu.insertItem( tr( "&Open form source..." ), OPEN_FORM_SOURCE );
-	menu.insertSeparator();
-	menu.insertItem( PixmapChooser::loadPixmap( "editcut" ),
+  menu.insertItem( i18n( "&Open Form Source..." ), OPEN_FORM_SOURCE );
+  menu.insertSeparator();
+  menu.insertItem( PixmapChooser::loadPixmap( "editcut" ),
 #ifndef KOMMANDER
-			 tr( "&Remove form from project" ), REMOVE_FORM );
+       i18n( "&Remove Form From Project" ), REMOVE_FORM );
 #else
-			 tr( "&Remove form" ), REMOVE_FORM );
+       i18n("&Remove Form" ), REMOVE_FORM );
 #endif
-	break;
+  break;
 #ifndef KOMMANDER
     case WorkspaceItem::ProjectType:
-	MainWindow::self->popupProjectMenu( pos );
-	return;
+  MainWindow::self->popupProjectMenu( pos );
+  return;
 #endif
     default:
-	return;
+  return;
     }
     switch ( menu.exec( pos ) ) {
 #ifndef KOMMANDER
     case REMOVE_SOURCE:
-	project->removeSourceFile( wi->sourceFile );
-	break;
+  project->removeSourceFile( wi->sourceFile );
+  break;
 #endif
     case OPEN_SOURCE:
-	itemClicked( LeftButton, i, pos );
-	break;
+  itemClicked( LeftButton, i, pos );
+  break;
 #ifndef KOMMANDER
     case REMOVE_FORM: // FIXME
-	project->removeFormFile( wi->formFile );
-	break;
+  project->removeFormFile( wi->formFile );
+  break;
 #endif
     case OPEN_FORM:
-	itemClicked( LeftButton, i, pos );
-	break;
+  itemClicked( LeftButton, i, pos );
+  break;
     case OPEN_FORM_SOURCE:
-	itemClicked( LeftButton, i, pos );
-	break;
+  itemClicked( LeftButton, i, pos );
+  break;
     default:
-	break;
+  break;
     }
 }
 
@@ -689,7 +722,7 @@ bool Workspace::eventFilter( QObject *o, QEvent * e )
 {
     // Reggie, on what type of events do we have to execute updateBufferEdit()
     if ( o ==bufferEdit && e->type() != QEvent::ChildRemoved )
-	updateBufferEdit();
+  updateBufferEdit();
     return QListView::eventFilter( o, e );
 }
 
@@ -697,20 +730,20 @@ void Workspace::setBufferEdit( QCompletionEdit *edit )
 {
     bufferEdit = edit;
     connect( bufferEdit, SIGNAL( chosen( const QString & ) ),
-	     this, SLOT( bufferChosen( const QString & ) ) );
+       this, SLOT( bufferChosen( const QString & ) ) );
     bufferEdit->installEventFilter( this );
 }
 
 void Workspace::updateBufferEdit()
 {
     if ( !bufferEdit || !completionDirty )
-	return;
+  return;
     completionDirty = FALSE;
 #ifndef KOMMANDER
     QStringList completion = MainWindow::self->projectFileNames();
     while ( it.current() ) {
-	( (WorkspaceItem*)it.current())->fillCompletionList( completion );
-	++it;
+  ( (WorkspaceItem*)it.current())->fillCompletionList( completion );
+  ++it;
     }
     completion.sort();
     bufferEdit->setCompletionList( completion );
@@ -720,22 +753,22 @@ void Workspace::updateBufferEdit()
 void Workspace::bufferChosen( const QString &buffer )
 {
     if ( bufferEdit )
-	bufferEdit->setText( "" );
+  bufferEdit->setText( "" );
 
 #ifndef KOMMANDER
     if ( MainWindow::self->projectFileNames().contains( buffer ) ) {
-	MainWindow::self->setCurrentProjectByFilename( buffer );
-	return;
+  MainWindow::self->setCurrentProjectByFilename( buffer );
+  return;
     }
 #endif
 
     QListViewItemIterator it( this );
     while ( it.current() ) {
-	if ( ( (WorkspaceItem*)it.current())->checkCompletion( buffer ) ) {
-	    itemClicked( LeftButton, it.current(), QPoint() );
-	    break;
-	}
-	++it;
+  if ( ( (WorkspaceItem*)it.current())->checkCompletion( buffer ) ) {
+      itemClicked( LeftButton, it.current(), QPoint() );
+      break;
+  }
+  ++it;
     }
 }
 
@@ -743,13 +776,13 @@ void Workspace::updateColors()
 {
     QListViewItem* i = firstChild();
     if ( i )
-	i = i->firstChild();
+  i = i->firstChild();
     bool b = TRUE;
     while ( i ) {
-	WorkspaceItem* wi = ( WorkspaceItem*) i;
-	i = i->nextSibling();
-	wi->useOddColor = b;
-	b = !b;
+  WorkspaceItem* wi = ( WorkspaceItem*) i;
+  i = i->nextSibling();
+  wi->useOddColor = b;
+  b = !b;
     }
 }
 #include "workspace.moc"
