@@ -49,12 +49,12 @@ static const char *description =
 static KCmdLineOptions options[] =
 {
   { "+[file]", I18N_NOOP("Dialog to open"), 0 },
-  { 0, 0, 0 }
+  KCmdLineLastOption
 };
 
 int main(int argc, char *argv[])
 {
-  KLocale::setMainCatalogue("kcommander");
+  KLocale::setMainCatalogue("kommander");
   KAboutData aboutData( "kmdr-executor", I18N_NOOP("Kommander Executor"),
     VERSION, description, KAboutData::License_GPL,
     "(c) 2002, Marc Britton", 0, 0, "consume@optushome.com.au");
