@@ -1,3 +1,18 @@
+/***************************************************************************
+                          assoctextwidget.cpp - Text widget functionality class 
+                             -------------------
+    copyright            : (C) 2002 by Marc Britton
+    email                : consume@optusnet.com.au
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 /* KDE INCLUDES */
 #include <kapplication.h>
 #include <dcopclient.h>
@@ -5,6 +20,7 @@
 
 /* QT INCLUDES */
 #include <qvariant.h>
+#include <qregexp.h>
 #include <qstringlist.h>
 #include <qcstring.h>
 #include <qdatastream.h>
@@ -44,11 +60,21 @@ QStringList AssocTextWidget::states() const
 	return m_states;
 }
 
+QStringList AssocTextWidget::displayStates() const
+{
+	return m_displayStates;
+}
+
 void AssocTextWidget::setStates(QStringList a_states)
 {
 	m_states = a_states;
 }
 
+void AssocTextWidget::setDisplayStates(QStringList a_displayStates)
+{
+	m_displayStates = a_displayStates;
+}
+
 QString AssocTextWidget::evalAssociatedText() const // expands and returns associated text as a string
 {
 	QString curState = currentState();
@@ -79,7 +105,7 @@ QString AssocTextWidget::evalAssociatedText(const QString &a_text) const
 		{
 			QString identifier;
 
-			for(++pos;pos < baseTextLength && baseText[pos].isLetterOrNumber();++pos)
+			for(++pos;pos < baseTextLength && (baseText[pos].isLetterOrNumber() || baseText[pos] == '_');++pos)
 				identifier += baseText[pos];
 
 			if(identifier.isEmpty())
