@@ -1,3 +1,18 @@
+/***************************************************************************
+                          closebutton.cpp - Button that when clicked, closes the dialog it's in
+                             -------------------
+    copyright            : (C) 2002 by Marc Britton
+    email                : consume@optusnet.com.au
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 /* KDE INCLUDES */
 #include <kmessagebox.h>
 #include <klocale.h>
@@ -20,6 +35,7 @@ CloseButton::CloseButton(QWidget *a_parent, const char *a_name)
 	QStringList states;
 	states << "default";
 	setStates(states);
+	setDisplayStates(states);
 	setWriteStdout(false);
 
 	connect(this, SIGNAL(clicked()), this, SLOT(startProcess()));
@@ -32,6 +48,8 @@ CloseButton::CloseButton(QWidget *a_parent, const char *a_name)
 			break;
 	}
 	connect(this, SIGNAL(clicked()), parent, SLOT(reject()));
+
+	emit widgetOpened();
 }
 
 CloseButton::~CloseButton()
@@ -84,7 +102,7 @@ void CloseButton::startProcess()
 
 		if(!process->start(KProcess::Block, KProcess::Stdout))
 		{
-			KMessageBox::error(this, i18n("Failed to start shell process"));
+			KMessageBox::error(this, i18n("Failed to start shell process."));
 			endProcess(process);
 			return;
 		}
@@ -114,10 +132,7 @@ void CloseButton::endProcess(KProcess *a_process)
 {
 	emit widgetTextChanged(m_output);
 	m_output = "";
-
-	if(a_process)
-		delete a_process;
-
+        delete a_process;
 }
 
 bool CloseButton::writeStdout() const
