@@ -23,10 +23,12 @@
 
 #include "ewidgetfactory.h"
 
-#include <eventinterface.h>
-#include <interpreterinterface.h>
-#include <languageinterface.h>
-#include <widgetinterface.h>
+#ifndef KOMMANDER
+#include "eventinterface.h"
+#include "interpreterinterface.h"
+#include "languageinterface.h"
+#endif
+#include "widgetinterface.h"
 
 #ifndef KOMMANDER
 #include <qwidgetfactory.h>
@@ -40,7 +42,7 @@
 #include <qdir.h>
 #include <qlayout.h>
 #include <qmetaobject.h>
-#include <domtool.h>
+#include "domtool.h"
 #include <qapplication.h>
 #include <qtooltip.h>
 #include <qwhatsthis.h>
@@ -75,7 +77,6 @@
 #include <qmultilineedit.h>
 #include <qlabel.h>
 #include <qwidget.h>
-#include <qwidgetstack.h>
 #include <qtabwidget.h>
 #include <qcombobox.h>
 #include <qdialog.h>
@@ -87,32 +88,36 @@
 #include <qdial.h>
 #include <qslider.h>
 #include <qframe.h>
+#include <qwidgetstack.h>
 #include <qtextedit.h>
 #include <qscrollbar.h>
 #include <qmainwindow.h>
 #include <qsplitter.h>
 #include <qaction.h>
+#include <qpopupmenu.h>
 #include <qmenubar.h>
 #include <qdatetimeedit.h>
-#include <qwidgetstack.h>
 
 /* KOMMANDER INCLUDES */
-#include "lineedit.h"
-#include "dialog.h"
-#include "execbutton.h"
-#include "closebutton.h"
-#include "fileselector.h"
-#include "textedit.h"
-#include "radiobutton.h"
-#include "buttongroup.h"
-#include "groupbox.h"
-#include "checkbox.h"
-#include "combobox.h"
-#include "spinboxint.h"
-#include "wizard.h"
-#include "tabwidget.h"
-#include "subdialog.h"
-#include "listbox.h"
+#include <lineedit.h>
+#include <dialog.h>
+#include <execbutton.h>
+#include <closebutton.h>
+#include <fileselector.h>
+#include <textedit.h>
+#include <radiobutton.h>
+#include <buttongroup.h>
+#include <groupbox.h>
+#include <checkbox.h>
+#include <combobox.h>
+#include <spinboxint.h>
+#include <wizard.h>
+#include <tabwidget.h>
+#include <subdialog.h>
+#include <listbox.h>
+#include <scriptobject.h>
+#include <richtexteditor.h>
+#include <treewidget.h>
 
 #include <stdlib.h>
 
@@ -121,9 +126,11 @@ static QPtrList<QWidgetFactory> widgetFactories;
 #else
 static QPtrList<EWidgetFactory> widgetFactories;
 #endif
+#ifndef KOMMANDER
 static QPluginManager<EventInterface> *eventInterfaceManager = 0;
 static QPluginManager<InterpreterInterface> *interpreterInterfaceManager = 0;
 static QPluginManager<LanguageInterface> *languageInterfaceManager = 0;
+#endif
 static QPluginManager<WidgetInterface> *widgetInterfaceManager = 0;
 
 QMap<QWidget*, QString> *qwf_functions = 0;
@@ -228,8 +235,6 @@ QWidget *EWidgetFactory::create( const QString &uiFile, QObject *connector, QWid
     return w;
 }
 
-#undef slots
-
 /*!  \overload
     Loads the user interface description from device \a dev.
  */
@@ -255,9 +260,9 @@ QWidget *EWidgetFactory::create( QIODevice *dev, QObject *connector, QWidget *pa
     while ( variables.tagName() != "variables" && !variables.isNull() )
 	variables = variables.nextSibling().toElement();
 
-    QDomElement slots = e;
-    while ( slots.tagName() != "slots" && !slots.isNull() )
-	slots = slots.nextSibling().toElement();
+    QDomElement eltSlots = e;
+    while ( eltSlots.tagName() != "slots" && !eltSlots.isNull() )
+	eltSlots = eltSlots.nextSibling().toElement();
 
     QDomElement connections = e;
     while ( connections.tagName() != "connections" && !connections.isNull() )
@@ -317,8 +322,8 @@ QWidget *EWidgetFactory::create( QIODevice *dev, QObject *connector, QWidget *pa
 	    if ( n.tagName() == "variable" )
 		widgetFactory->variables << n.firstChild().toText().data();
     }
-    if ( !slots.isNull() ) {
-	for ( QDomElement n = slots.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() )
+    if ( !eltSlots.isNull() ) {
+	for ( QDomElement n = eltSlots.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() )
 	    if ( n.tagName() == "slot" ) {
 		QString s = n.firstChild().toText().data();
 		widgetFactory->languageSlots.insert( s.left( s.find( "(" ) ) , n.attribute( "language", "C++" ) );
@@ -341,10 +346,12 @@ QWidget *EWidgetFactory::create( QIODevice *dev, QObject *connector, QWidget *pa
 	widgetFactory->loadTabOrder( tabOrder );
 
 
+#ifndef KOMMANDER
     if ( !functions.isNull() ) // compatibiliy with early 3.0 betas
 	widgetFactory->loadFunctions( functions );
+#endif
 
-
+#ifndef KOMMANDER
     if ( !languageInterfaceManager )
 	languageInterfaceManager = new QPluginManager<LanguageInterface>( IID_Language, QApplication::libraryPaths(), "" );
     if ( !interpreterInterfaceManager )
@@ -352,6 +359,7 @@ QWidget *EWidgetFactory::create( QIODevice *dev, QObject *connector, QWidget *pa
 	    new QPluginManager<InterpreterInterface>( IID_Interpreter, QApplication::libraryPaths(), "" );
 
     widgetFactory->loadExtraSource();
+#endif
 
     if ( widgetFactory->toplevel ) {
 #ifndef QT_NO_SQL
@@ -389,6 +397,7 @@ QWidget *EWidgetFactory::create( QIODevice *dev, QObject *connector, QWidget *pa
 	}
 #endif
 
+#ifndef KOMMANDER
 	if ( !eventInterfaceManager )
 	    eventInterfaceManager = new QPluginManager<EventInterface>( IID_Event, QApplication::libraryPaths(), "" );
 
@@ -432,6 +441,7 @@ QWidget *EWidgetFactory::create( QIODevice *dev, QObject *connector, QWidget *pa
 		}
 	    }
 	}
+#endif
 
     }
 
@@ -543,6 +553,12 @@ QWidget *EWidgetFactory::createWidget( const QString &literalClassName, QWidget
 		return new SubDialog(parent, name);
 	else if(className == "ListBox")
 		return new ListBox(parent, name);
+	else if(className == "ScriptObject")
+		return new ScriptObject(parent, name);
+	else if(className == "RichTextEditor")
+		return new RichTextEditor(parent, name);
+	else if(className == "TreeWidget")
+	    return new TreeWidget(parent, name);
 
     // create widgets we know
     if ( className == "QPushButton" ) {
@@ -649,6 +665,7 @@ QWidget *EWidgetFactory::createWidget( const QString &literalClassName, QWidget
     }
 #endif
 
+/* Probably don't need this in Kommander. Widgets come from the factory. */
     // try to create it using the loaded widget plugins
     if ( !widgetInterfaceManager )
 	widgetInterfaceManager = new QPluginManager<WidgetInterface>( IID_Widget, QApplication::libraryPaths(), "" );
@@ -1630,6 +1647,7 @@ void EWidgetFactory::loadMenuBar( const QDomElement &e )
 
 
 // compatibility with early 3.0 betas
+#ifndef KOMMANDER
 void EWidgetFactory::loadFunctions( const QDomElement &e )
 {
     QDomElement n = e.firstChild().toElement();
@@ -1675,6 +1693,7 @@ void EWidgetFactory::loadFunctions( const QDomElement &e )
 	n = n.nextSibling().toElement();
     }
 }
+#endif
 
 QAction *EWidgetFactory::findAction( const QString &name )
 {
@@ -1708,6 +1727,7 @@ void EWidgetFactory::loadImages( const QString &dir )
 
 }
 
+#ifndef KOMMANDER
 void EWidgetFactory::loadExtraSource()
 {
     if ( !qwf_language || !languageInterfaceManager )
@@ -1787,6 +1807,7 @@ void EWidgetFactory::loadExtraSource()
     for ( vit = vars.begin(); vit != vars.end(); ++vit )
 	variables << *vit;
 }
+#endif
 
 QString EWidgetFactory::translate( const QString& sourceText, const QString& comment )
 {
