@@ -1,3 +1,18 @@
+/***************************************************************************
+                          execbutton.cpp - Button that runs its text association
+                             -------------------
+    copyright            : (C) 2002 by Marc Britton
+    email                : consume@optusnet.com.au
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 /* KDE INCLUDES */
 #include <kprocess.h>
 #include <kmessagebox.h>
@@ -20,9 +35,12 @@ ExecButton::ExecButton(QWidget *a_parent, const char *a_name)
 	QStringList states;
 	states << "default";
 	setStates(states);
+	setDisplayStates(states);
 	setWriteStdout(false);
 
 	connect(this, SIGNAL(clicked()), this, SLOT(startProcess()));
+
+	emit widgetOpened();
 }
 
 ExecButton::~ExecButton()
@@ -72,18 +90,12 @@ void ExecButton::startProcess()
 		connect(process, SIGNAL(processExited(KProcess *)), SLOT(endProcess(KProcess *)));
 		connect(process, SIGNAL(receivedStdout(KProcess *, char *, int)), SLOT(appendOutput(KProcess *, char *, int)));
 		connect(process, SIGNAL(receivedStderr(KProcess *, char *, int)), SLOT(appendOutput(KProcess *, char *, int)));
-		// FIXME : This is seriously screwed. I think the app needs to be executing for start to work. This means changing back AGAIN to modeless dialogs
-#if 1
 		if(!process->start(KProcess::NotifyOnExit, KProcess::Stdout))
 		{
 			KMessageBox::error(this, i18n("Failed to start shell process"));
 			delete process;
 			return;
 		}
-#else
-		// Screw it, don't check for errors ;)
-		process->start(KProcess::NotifyOnExit, KProcess::Stdout);
-#endif
 
 		setEnabled(false); // disabled until process ends
 	}
