@@ -1,3 +1,18 @@
+/***************************************************************************
+                          fileselector.h - File selection widget
+                             -------------------
+    copyright            : (C) 2002 by Marc Britton
+    email                : consume@optusnet.com.au
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 #ifndef _HAVE_FILESELECTOR_H_
 #define _HAVE_FILESELECTOR_H_
 
@@ -54,6 +69,7 @@ public slots:
 	virtual void setWidgetText(const QString &);
 	virtual void makeSelection();
 signals:
+	void widgetOpened();
 	void widgetTextChanged(const QString &);
 protected:
 	bool m_openMultiple;
