@@ -2,8 +2,8 @@
                           previewoptions.h  -  description
                              -------------------
     begin                : Fri Aug 4 2000
-    copyright            : (C) 2000 by Dmitry Poplavsky & Alexander Yakovlev & Eric Laffoon
-    email                : pdima@users.sourceforge.net,yshurik@penguinpowered.com,sequitur@easystreet.com
+    copyright            : (C) 2000 by Dmitry Poplavsky & Alexander Yakovlev & Eric Laffoon <pdima@users.sourceforge.net,yshurik@penguinpowered.com,sequitur@easystreet.com>
+                           (C) 2002 Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -24,15 +24,18 @@ class KConfig;
 
 class PreviewOptions : public PreviewOptionsS  {
    Q_OBJECT
-public: 
-	PreviewOptions(QWidget *parent=0, const char *name=0);
-	~PreviewOptions();
+public:
+  PreviewOptions(QWidget *parent=0, const char *name=0);
+  ~PreviewOptions();
+
+  QString position();
+  QString layout();
+  void setPosition(const QString& );
+  void setWindowLayout(const QString& );
 
-	QString position();
-	void setPosition( QString );
-	
 public slots:
-	void slotToggle();
+  void slotToggleWindowLayout();
+  void slotTogglePreview();
 };
 
 #endif
