@@ -5,7 +5,7 @@
     Copyright (c) 1999-2001 the KNode authors.
     See file AUTHORS for details
 
-    Rewritten for Quanta Plus: (C) 2002 Andras Mantia <amantia@freemail.hu>
+    Rewritten for Quanta Plus: (C) 2002, 2003 Andras Mantia <amantia@kde.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,32 +18,41 @@
 
 #include <qtimer.h>
 
+#include <kconfig.h>
+#include <kdebug.h>
 #include <kwin.h>
 #include <kcmdlineargs.h>
 #include <kurl.h>
 #include <kiconloader.h>
 #include <kstandarddirs.h>
+#include <kglobalsettings.h>
+#include <dcopclient.h>
 
 #include "quantacommon.h"
-#include "project/project.h"
+#include "project.h"
 #include "quanta.h"
 #include "kqapp.h"
 
-
+ 
 QuantaApp *quantaApp = 0L; //global pointer to the main application object
 
 KSplash::KSplash()
  : QFrame( 0L, QString("Quanta")+VERSION,
-	QWidget::WStyle_NoBorder | QWidget::WStyle_Customize)
+   QWidget::WStyle_NoBorder | QWidget::WStyle_Customize | WX11BypassWM)
 {
-	QPixmap pm( UserIcon("quantalogo") );
+   QPixmap pm( UserIcon("quantalogo") );
 
-	setBackgroundPixmap(pm);
-        setGeometry( QApplication::desktop()->width ()/2-225,
-                     QApplication::desktop()->height()/2-150,
-                     450, 300 );
-  	setLineWidth(0);
-	show();
+   setBackgroundPixmap(pm);
+#if KDE_VERSION >= KDE_MAKE_VERSION(3,1,90)
+  QRect desk = KGlobalSettings::splashScreenDesktopGeometry();
+  setGeometry( desk.center().x()-225, desk.center().y()-150, 450, 300 );
+#else
+  setGeometry( QApplication::desktop()->width ()/2-225,
+                QApplication::desktop()->height()/2-150,
+                450, 300 );
+#endif
+   setLineWidth(0);
+   show();
 }
 
 
@@ -58,19 +67,28 @@ KQApplication::KQApplication()
    splash = 0L;
 
    KGlobal::dirs()->addPrefix(PREFIX);
+   dcopClient()->registerAs("quanta", true);
 
-   if (args->isSet("logo")) splash = new KSplash();
-/*
-   if (isRestored())
+//FIXME: Do not hide the problem, but really fix the session restoration.
+//I have no idea how to do it, but it may be broken because of delayed
+//initialization in QuantaApp
+/*   if (isRestored())
    {
      RESTORE(QuantaApp);
    }
-   else
-*/   
+   else */
    {
      quantaApp = new QuantaApp();
+     KConfig *config = quantaApp->config();
+     config->setGroup("General Options");
+     if (config->readBoolEntry("Show Splash", true) && args->isSet("logo"))
+     {
+       splash = new KSplash();
+       connect(quantaApp, SIGNAL(showSplash(bool)), splash, SLOT(setShown(bool)));
+       QTimer::singleShot(10*1000, this, SLOT(slotSplashTimeout()));
+     }
      setMainWidget(quantaApp);
-     QTimer::singleShot(10, this, SLOT( slotInit()));
+     slotInit();
    }
 }
 
@@ -83,13 +101,19 @@ KQApplication::~KQApplication()
 {
 }
 
+void KQApplication::slotSplashTimeout()
+{
+  delete splash;
+  splash = 0L;
+}
+
 KQUniqueApplication::KQUniqueApplication()
  : KUniqueApplication()
 {
   KGlobal::dirs()->addPrefix(PREFIX);
+  dcopClient()->registerAs("quanta", false);
 }
 
-
 KQUniqueApplication::~KQUniqueApplication()
 {
 }
@@ -100,9 +124,14 @@ int KQUniqueApplication::newInstance()
   args = KCmdLineArgs::parsedArgs();
   if (mainWidget())
   {
-    KWin::setActiveWindow(mainWidget()->winId());
+#if KDE_VERSION < KDE_MAKE_VERSION( 3, 1, 90 )
+	KWin::setActiveWindow( mainWidget()->winId() );
+#else
+	KWin::activateWindow( mainWidget()->winId() );
+#endif
+
     quantaApp = static_cast<QuantaApp*>(mainWidget());
-    for (int i = 0; i < args->count(); i++) 
+    for (int i = 0; i < args->count(); i++)
     {
       quantaApp->slotFileOpen(args->url(i), quantaApp->defaultEncoding());  // load initial files
     }
@@ -110,11 +139,17 @@ int KQUniqueApplication::newInstance()
   else
   {
     splash = 0L;
-    if (args->isSet("logo")) splash = new KSplash();
-
     quantaApp = new QuantaApp();
+    KConfig *config = quantaApp->config();
+    config->setGroup("General Options");
+    if (config->readBoolEntry("Show Splash", true) && args->isSet("logo"))
+    {
+      splash = new KSplash();
+      connect(quantaApp, SIGNAL(showSplash(bool)), splash, SLOT(setShown(bool)));
+      QTimer::singleShot(10*1000, this, SLOT(slotSplashTimeout()));
+    }
     setMainWidget(quantaApp);
-    QTimer::singleShot(10, this, SLOT( slotInit()));
+    slotInit();
   }
 
   return 0;
@@ -125,6 +160,13 @@ void KQUniqueApplication::slotInit()
   KQApplicationPrivate::init();
 }
 
+void KQUniqueApplication::slotSplashTimeout()
+{
+  delete splash;
+  splash = 0L;
+}
+
+
 void KQApplicationPrivate::init()
 {
   if (quantaApp->quantaStarted)
@@ -143,18 +185,21 @@ void KQApplicationPrivate::init()
       else
         initialFiles += arg;
     }
-
     quantaApp->loadInitialProject(initialProject);
+    //recoverCrashed manages the autosaved copies
+    quantaApp->recoverCrashed(initialFiles);
+
     for(QStringList::Iterator it = initialFiles.begin();it != initialFiles.end();++it)
     {
       KURL url;
-      QuantaCommon::setUrl(url, *it);
+      QuantaCommon::setUrl(url, (*it));
       quantaApp->slotFileOpen(url, quantaApp->defaultEncoding());  // load initial files
     }
     quantaApp->openLastFiles();
   }
   args->clear();
-  if (splash) delete splash;
+  delete splash;
+  splash = 0L;
 }
 
 #include "kqapp.moc"
