@@ -2,8 +2,8 @@
                           messageoutput.cpp  -  description
                              -------------------
     begin                : Thu Feb 24 2000
-    copyright            : (C) 2000 by Yacovlev Alexander & Dmitry Poplavski
-    email                : pdima@mail.univ.kiev.ua
+    copyright            : (C) 2000 by Yacovlev Alexander & Dmitry Poplavski <pdima@mail.univ.kiev.ua>
+                           (C) 2003 Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,36 +21,33 @@
 #include "messageitem.h"
 #include "messageitemphp.h"
 #include "messageitemphp4.h"
-#include "messageitemweblint.h"
 
 MessageOutput::MessageOutput(QWidget *parent, const char *name )
   : QListBox(parent,name)
 {
   max_items = 200;
-  insertItem( i18n("Message window...") );
-  insertItem("");
+
   QPalette pal = palette();
   pal.setColor(QColorGroup::HighlightedText, pal.color(QPalette::Normal, QColorGroup::Text));
   pal.setColor(QColorGroup::Highlight,       pal.color(QPalette::Normal, QColorGroup::Mid));
   setPalette(pal);
   setFocusPolicy( NoFocus );
 
-  connect( this, SIGNAL(pressed(QListBoxItem*)), SLOT(clickItem(QListBoxItem*)) );
-
+  connect( this, SIGNAL(selected(QListBoxItem*)), SLOT(clickItem(QListBoxItem*)) );
 }
 
 MessageOutput::~MessageOutput()
 {
 }
 
-void MessageOutput::insertItem(QString s)
+void MessageOutput::insertItem(const QString& s)
 {
   checkMaxItems();
-  new MessageItem(this,s);
+  new MessageItem(this, s);
   setBottomItem(count()>0?count()-1:0);
 }
 
-void MessageOutput::addToLastItem(QString s)
+void MessageOutput::addToLastItem(const QString& s)
 {
   int ind = count()-1;
   if ( ind != -1 ) {
@@ -58,24 +55,24 @@ void MessageOutput::addToLastItem(QString s)
     if ( it )
       it->addText( s );
     else
-      changeItem( text( ind )+s, ind );
+      changeItem( text( ind )+ s, ind );
   }
 }
 
 
-void MessageOutput::showMessage( QString message )
+void MessageOutput::showMessage(const QString& s)
 {
+  QString message = s;
   int endPos;
   if ( !count() )
     insertItem("");
-
   while ( ( endPos = message.find('\n') ) != -1 ) {
     addToLastItem( message.left(endPos) );
     insertItem("");
     message.remove(0,endPos+1);
   }
-
-  addToLastItem( message );
+  if (!message.isEmpty())
+      addToLastItem( message);
   setBottomItem(count()>0?count()-1:0);
 }
 
@@ -95,7 +92,7 @@ void MessageOutput::clickItem( QListBoxItem * l_item )
    }
 }
 
-void MessageOutput::phpDebug( QString s)
+void MessageOutput::phpDebug(const QString& s)
 {
    static QString data = "";
    data += s;
@@ -113,7 +110,7 @@ void MessageOutput::phpDebug( QString s)
 
 }
 
-void MessageOutput::php4Debug( QString s)
+void MessageOutput::php4Debug(const QString& s)
 {
   new MessageItemPHP4( this, s );
   setBottomItem(count()-1);
@@ -129,42 +126,4 @@ void MessageOutput::endPhpConnect()
    insertItem("");
 }
 
-// if p!=0 store output, else show it
-void MessageOutput::processWebLint( KProcess *p, char *buffer, int len )
-{
-  static QString s = "";
-
-  if ( p ) {
-    QString text(buffer);
-    text.truncate(len);
-    s += text;
-  }
-  else {
-    int endPos;
-    if ( s.right(1) == "\n" )
-      s.remove( s.length()-1,1 );
-    if ( s.left(1) == "\n" )
-      s.remove( 0,1 );
-
-    while ( ( endPos = s.find('\n') ) != -1 ) {
-      new MessageItemWebLint( this, s.left(endPos) );
-      s.remove(0,endPos+1);
-    }
-    if( ! s.isEmpty() ) {
-      new MessageItemWebLint( this, s );
-    }
-   // setBottomItem(count()-1);
-    s = "";
-  }
-  setBottomItem(count()>0?count()-1:0);
-
-}
-
-void MessageOutput::weblintFinished()
-{
-   clear();
-   processWebLint(0,0,0); // show output
-   new MessageItemWebLint( this, i18n("Syntax check done.") );
-}
-
 #include "messageoutput.moc"
