@@ -10,15 +10,15 @@ class PHP3Debugger : public QServerSocket  {
     PHP3Debugger( int port, QObject *parent=0, const char *name=0 );
 
     virtual void newConnection( int socket );
-  
+
   public slots:
     void readClient();
     void discardClient();
-      
+
   signals:
     void newConnect();
     void endConnect();
-    void data( QString );
+    void data(const QString& );
     void wroteToClient();
 };
 
