@@ -11,9 +11,7 @@
                            the world-wide-web at http://dd.cron.ru/license
  ***************************************************************************/
 
-#include "dbg_core.h"
 #include "ListenerBase.h"
-#include "ThreadBase.h"
 #include <stdio.h>
 #include <assert.h>
 
@@ -132,7 +130,7 @@ void ListenerBase::logstatus() {
 			break;
 		case LSTNRS_initerror:
 			oserrnostr(buf, sizeof(buf), _error);
-			snprintf(sbuf, sizeof(sbuf)-1, (char *)"Error '%s' (OSERR=%d) occured.", buf, _error);
+			snprintf(sbuf, sizeof(sbuf)-1, (char *)"Error '%s' (OSERR=%d) occurred.", buf, _error);
 			log(LSTNRL_error,sbuf);
 			break;
 		case LSTNRS_stopped:
