@@ -2,8 +2,8 @@
                           quantaplugineditor.cpp  -  description
                              -------------------
     begin                : Fri Sep 20 2002
-    copyright            : (C) 2002 by Marc Britton
-    email                : consume@optushome.com.au
+    copyright            : (C) 2002 by Marc Britton <consume@optushome.com.au>
+                           (C) 2003 by Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -21,6 +21,7 @@
 #include <kglobal.h>
 #include <klocale.h>
 #include <kicondialog.h>
+#include <kdialogbase.h>
 
 /* QT INCLUDES */
 #include <qwidget.h>
@@ -30,32 +31,35 @@
 #include <qpushbutton.h>
 #include <qlineedit.h>
 #include <qcombobox.h>
+#include <qlistview.h>
 
 /* OTHER INCLUDES */
 #include "quantaplugineditor.h"
 #include "quantaplugin.h"
-#include "quantakpartplugin.h"
-#include "quantacmdplugin.h"
 #include "quantapluginconfig.h"
 #include "quantaplugininterface.h"
-#include "../quanta.h"
-#include "../resource.h"
+#include "pluginconfig.h"
+#include "plugineditor.h"
+#include "quanta.h"
+#include "resource.h"
 
 QuantaPluginEditor::QuantaPluginEditor(QWidget *a_parent, const char *a_name)
-  : PluginEditor(a_parent, a_name)
+  : KDialogBase(a_parent, a_name, true, i18n("Edit Plugins"), KDialogBase::Ok | KDialogBase::Cancel)
 {
  // m_plugins.setAutoDelete(TRUE);
 
-  pluginList->setSelectionMode(QListView::Single);
-  pluginList->setAllColumnsShowFocus(TRUE);
-  pluginList->setColumnAlignment(2, Qt::AlignHCenter);  
-  
+  m_pluginEditorWidget = new PluginEditor(this);
+  setMainWidget(m_pluginEditorWidget);
+  m_pluginEditorWidget->pluginList->setSelectionMode(QListView::Single);
+  m_pluginEditorWidget->pluginList->setAllColumnsShowFocus(TRUE);
+  m_pluginEditorWidget->pluginList->setColumnAlignment(2, Qt::AlignHCenter);
+
   connect(this, SIGNAL(pluginsChanged()), SLOT(refreshPlugins()));
-  connect(refreshButton, SIGNAL(clicked()), SLOT(refreshPlugins()));
-  connect(addButton, SIGNAL(clicked()), SLOT(addPlugin()));
-  connect(removeButton, SIGNAL(clicked()), SLOT(removePlugin()));
-  connect(addSearchPathButton, SIGNAL(clicked()), SLOT(addSearchPath()));
-  connect(configureButton, SIGNAL(clicked()), SLOT(configurePlugin()));
+  connect(m_pluginEditorWidget->refreshButton, SIGNAL(clicked()), SLOT(refreshPlugins()));
+  connect(m_pluginEditorWidget->addButton, SIGNAL(clicked()), SLOT(addPlugin()));
+  connect(m_pluginEditorWidget->removeButton, SIGNAL(clicked()), SLOT(removePlugin()));
+  connect(m_pluginEditorWidget->addSearchPathButton, SIGNAL(clicked()), SLOT(addSearchPath()));
+  connect(m_pluginEditorWidget->configureButton, SIGNAL(clicked()), SLOT(configurePlugin()));
 }
 
 QuantaPluginEditor::~QuantaPluginEditor()
@@ -67,41 +71,26 @@ QDict<QuantaPlugin> QuantaPluginEditor::plugins()
   return m_plugins;
 }
 
-void QuantaPluginEditor::accept()
-{
-  QDialog::accept();
-}
-
 void QuantaPluginEditor::addPlugin()
 {
   // new plugin config menu
   // create new plugin and add to list
   QuantaPluginConfig *configDlg = new QuantaPluginConfig(this, "pluginConfig");
+  PluginConfig *configWidget = static_cast<PluginConfig*>(configDlg->mainWidget());
 
   if(configDlg->exec())
   {
     // plugin accepted, create the proper type
     QuantaPlugin *newPlugin = 0;
-    QString pluginType = configDlg->pluginType->currentText();
-    if(pluginType == i18n("KPart"))
-      newPlugin = new QuantaKPartPlugin();
-    else if(pluginType == i18n("Command Line"))
-      newPlugin = new QuantaCmdPlugin();
-    else
-    {
-      qWarning("Tried to create unknown plugin type %s", pluginType.latin1());
-      return;
-    }
- 
-    newPlugin->setPluginName(configDlg->pluginName->text());
-    newPlugin->setFileName(configDlg->pluginFileName->text());
-    newPlugin->setType(configDlg->pluginType->currentText());
-    newPlugin->setLocation(configDlg->location->text());
-    newPlugin->setArguments(configDlg->arguments->text());
-    newPlugin->setOutputWindow(configDlg->outputWindow->currentText());
+    newPlugin = new QuantaPlugin();
+
+    newPlugin->setPluginName(configWidget->pluginName->text());
+    newPlugin->setFileName(configWidget->pluginFileName->text());
+    newPlugin->setLocation(configWidget->location->text());
+    newPlugin->setOutputWindow(configWidget->outputWindow->currentText());
     newPlugin->setStandard(false);
-    newPlugin->setIcon(configDlg->iconButton->icon());
-	  QString pluginName = newPlugin->pluginName();
+    newPlugin->setIcon(configWidget->iconButton->icon());
+    QString pluginName = newPlugin->pluginName();
     m_plugins.insert(pluginName, newPlugin);
     emit pluginsChanged();
   }
@@ -112,9 +101,9 @@ void QuantaPluginEditor::addSearchPath()
 {
   // Get a dir and append it to the line edit
   QString appendDir = KFileDialog::getExistingDirectory(QString::null, 0, i18n("Select Directory"));
-  if(appendDir != QString::null)
+  if(!appendDir.isNull())
   {
-   searchPaths->setText(searchPaths->text()+appendDir+":"); 
+    m_pluginEditorWidget->searchPaths->setText(m_pluginEditorWidget->searchPaths->text()+appendDir+":");
   }
 }
 
@@ -122,54 +111,53 @@ void QuantaPluginEditor::configurePlugin()
 {
   // create a new config dialog. populate with plugin data
   QString key;
-  QListViewItem *item = pluginList->currentItem();
+  QListViewItem *item = m_pluginEditorWidget->pluginList->currentItem();
   if(item)
     key = item->text(0);
-    
-  if(key != QString::null && m_plugins.find(key))
+
+  if(!key.isNull() && m_plugins.find(key))
   {
     QuantaPluginConfig *configDlg = new QuantaPluginConfig(this, "pluginConfig");
     QuantaPlugin *curPlugin = m_plugins.find(key);
+    PluginConfig *configWidget = static_cast<PluginConfig*>(configDlg->mainWidget());
 
-    configDlg->pluginType->setCurrentText(curPlugin->type());
-    configDlg->updateWindows(curPlugin->type()); //FIXME : hack
-    configDlg->outputWindow->setCurrentText(curPlugin->outputWindow());
-    configDlg->pluginName->setText(curPlugin->pluginName());
-    configDlg->pluginFileName->setText(curPlugin->fileName());        
-    configDlg->location->setText(curPlugin->location());
-    configDlg->arguments->setText(curPlugin->arguments());
-    configDlg->iconButton->setIcon(curPlugin->icon());
+    configWidget->outputWindow->setCurrentText(curPlugin->outputWindow());
+    configWidget->pluginName->setText(curPlugin->pluginName());
+    configWidget->pluginFileName->setText(curPlugin->fileName());
+    configWidget->location->setText(curPlugin->location());
+    configWidget->iconButton->setIcon(curPlugin->icon());
+    configWidget->inputBox->setCurrentItem(curPlugin->input());
+    configWidget->readOnlyBox->setChecked(curPlugin->readOnlyPart());
 
     if(configDlg->exec())
     {
-      curPlugin->setPluginName(configDlg->pluginName->text());
-      curPlugin->setFileName(configDlg->pluginFileName->text());
-      curPlugin->setType(configDlg->pluginType->currentText());
-      curPlugin->setLocation(configDlg->location->text());
-      curPlugin->setArguments(configDlg->arguments->text());
-      curPlugin->setOutputWindow(configDlg->outputWindow->currentText());
-      curPlugin->setIcon(configDlg->iconButton->icon());      
+      curPlugin->setPluginName(configWidget->pluginName->text());
+      curPlugin->setFileName(configWidget->pluginFileName->text());
+      curPlugin->setLocation(configWidget->location->text());
+      curPlugin->setOutputWindow(configWidget->outputWindow->currentText());
+      curPlugin->setIcon(configWidget->iconButton->icon());
+      curPlugin->setInput(configWidget->inputBox->currentItem());
+      curPlugin->setReadOnlyPart(configWidget->readOnlyBox->isChecked());
     }
-    
+
     delete configDlg;
-    
+
     emit pluginsChanged();
-  }  
+  }
 }
 
 void QuantaPluginEditor::refreshPlugins()
 {
   // call validate on all plugins to refresh their status
-  pluginList->clear();
-  
+  m_pluginEditorWidget->pluginList->clear();
+
   QDictIterator<QuantaPlugin> it(m_plugins);
   for(;it.current();++it)
   {
-    QListViewItem *newItem = new PluginEditorItem(pluginList);
+    QListViewItem *newItem = new PluginEditorItem(m_pluginEditorWidget->pluginList);
     QuantaPlugin *curPlugin = it.current();
 
     newItem->setText(0, curPlugin->pluginName());
-    newItem->setText(1, curPlugin->type());
 
     QPixmap statusIcon;
     bool isValid = QuantaPlugin::validatePlugin(curPlugin);
@@ -177,36 +165,35 @@ void QuantaPluginEditor::refreshPlugins()
       statusIcon = SmallIcon("pluginValid", KGlobal::instance());
     else
       statusIcon = SmallIcon("pluginInvalid", KGlobal::instance());
-    newItem->setPixmap(2, statusIcon);
-    
-    newItem->setText(3, curPlugin->location());
-    newItem->setText(4, curPlugin->fileName());
-    newItem->setText(5, curPlugin->arguments());
-    newItem->setText(6, curPlugin->outputWindow());
+    newItem->setPixmap(1, statusIcon);
 
-    pluginList->insertItem(newItem);
+    newItem->setText(2, curPlugin->location());
+    newItem->setText(3, curPlugin->fileName());
+    newItem->setText(4, curPlugin->outputWindow());
+
+    m_pluginEditorWidget->pluginList->insertItem(newItem);
   }
 }
 
 void QuantaPluginEditor::removePlugin()
 {
-  QListViewItem *currentItem = pluginList->currentItem();
-  if(currentItem)
+  QListViewItem *currentItem = m_pluginEditorWidget->pluginList->currentItem();
+  if (currentItem)
   {
-  	QuantaPlugin *plugin = m_plugins.find(currentItem->text(0));;
-  	if(plugin)
+    QuantaPlugin *plugin = m_plugins.find(currentItem->text(0));
+    if(plugin)
     {
-   	  m_plugins.remove(plugin->pluginName());
+      m_plugins.remove(plugin->pluginName());
       delete plugin;
       emit pluginsChanged();
     }
-  }    
+  }
 }
 
 void QuantaPluginEditor::setPlugins(QDict<QuantaPlugin> a_plugins)
 {
   m_plugins = a_plugins;
-  
+
   emit pluginsChanged();
 }
 
@@ -233,14 +220,14 @@ void QuantaPluginEditor::setSearchPaths(const QStringList& paths)
   {
     str += paths[i] +":";
   }
-  searchPaths->setText(str);
+  m_pluginEditorWidget->searchPaths->setText(str);
 }
 /** No descriptions */
 QStringList QuantaPluginEditor::searchPathList()
 {
-  QString str = searchPaths->text();
+  QString str = m_pluginEditorWidget->searchPaths->text();
   QStringList paths = QStringList::split(":",str);
-  
+
   return paths;
 }
 
