@@ -1,9 +1,9 @@
 /***************************************************************************
-    quantaplugininterface.cpp  - General interface to the plugin system 
+    quantaplugininterface.cpp  - General interface to the plugin system
                              -------------------
     begin                : Mon Sep 16 2002
-    copyright            : (C) 2002 by Marc Britton
-    email                : consume@optushome.com.au
+    copyright            : (C) 2002 by Marc Britton <consume@optushome.com.au>
+                           (C) 2003 by Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,6 +19,8 @@
 #include <kconfig.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
+#include <kdebug.h>
+#include <kmessagebox.h>
 
 /* QT INCLUDES */
 #include <qdict.h>
@@ -29,17 +31,13 @@
 
 /* OTHER INCLUDES */
 #include "quantaplugininterface.h"
-#include "quantakpartplugin.h"
-#include "quantacmdplugin.h"
-#include "cervisiaplugin.h"
-#include "../resource.h"
-#include "../quanta.h"
+#include "resource.h"
+#include "quanta.h"
+#include "quantacommon.h"
 
 QuantaPluginInterface::QuantaPluginInterface()
 {
  // m_plugins.setAutoDelete(TRUE);
-  
-  readConfig();
 }
 
 QuantaPluginInterface::~QuantaPluginInterface()
@@ -48,15 +46,8 @@ QuantaPluginInterface::~QuantaPluginInterface()
   // TODO : free plugins
 }
 
-/** Reads the plugin settings from the rc file */
-void QuantaPluginInterface::readConfig()
+void QuantaPluginInterface::readConfigFile(const QString& configFile)
 {
-  m_plugins.clear();
-
-  // read the plugins.rc
-  QString configFile = locateLocal("appdata", "plugins.rc");
-  if (!QFileInfo(configFile).exists()) configFile = qConfig.globalDataDir +"quanta/plugins.rc";
-  
   KConfig *config = new KConfig(configFile);
   config->setGroup("General");
   QStringList pList = config->readListEntry("Plugins");
@@ -66,61 +57,76 @@ void QuantaPluginInterface::readConfig()
 
   QStringList paths = config->readListEntry("SearchPaths");
   for(QStringList::Iterator it = paths.begin();it != paths.end(); ++it)
-    (*it) = (*it).stripWhiteSpace();  
+    (*it) = (*it).stripWhiteSpace();
   setSearchPaths(paths);
-         
+
   // now that we have a list of the plugins, go through and get the details of them
   for(QStringList::Iterator it = pList.begin();it != pList.end();++it)
   {
+    if (m_plugins.find(*it))
+        continue;
     config->setGroup(*it);
 
     QuantaPlugin *newPlugin = 0;
-    QString pluginType = config->readEntry("Type", "Command Line");
-    if (pluginType == "KPart") pluginType = i18n("KPart");
-    if (pluginType == "Command Line") pluginType = i18n("Command Line");
+    QString pluginType = config->readEntry("Type", "KPart");
     bool isStandard = config->readBoolEntry("Standard",false);
-    if (isStandard)
+/*    if (isStandard)
     {
       QString stdName = config->readEntry("Standard Name");
-      if (stdName == "cervisia_kpart")
-      {
-        newPlugin = new CervisiaPlugin();
-      }
       if (newPlugin)
       {
         newPlugin->setStandardName(stdName);
       }
-    } else
+    } else */
     {
-      if(pluginType == i18n("KPart"))
-        newPlugin = new QuantaKPartPlugin();
-      else if(pluginType == i18n("Command Line"))
-        newPlugin = new QuantaCmdPlugin();
-    }
-    if (!newPlugin)
-    {
-      qWarning("Unknown plugin type: %s", pluginType.latin1());
-      continue;
+      if (pluginType == "Command Line")
+      {
+        emit hideSplash();
+        KMessageBox::information(quantaApp, i18n("<qt><b>%1</b> is a command line plugin. We have removed support for command line plugins. However, the functionality has not been lost as script actions can still be used to run commandline tools. </qt>").arg(*it), i18n("Unsupported plugin type"), "CommandLinePluginWarning");
+        continue;
+      }
+
+      newPlugin = new QuantaPlugin();
     }
     newPlugin->setStandard(isStandard);
     newPlugin->setPluginName(*it);
     newPlugin->setFileName(config->readEntry("FileName"));
     newPlugin->setLocation(config->readEntry("Location"));
-    newPlugin->setType(pluginType);
-    newPlugin->setArguments(config->readEntry("Arguments"));
     newPlugin->setIcon(config->readEntry("Icon"));
     QString type = config->readEntry("OutputWindow");
-    if (type == "Editor View") type = i18n("Editor View");
-    if (type == "Message Window") type = i18n("Message Window");
-    if (type == "Konsole") type = i18n("Konsole");
-	if (type == "Output Dock") type = i18n("Output Dock");
+    if (type == "Editor Tab" || type == "Editor View")
+      type = i18n("Editor Tab"); //TODO: Remove the check against Editor View after 3.2
+    if (type == "Editor Frame")
+      type = i18n("Editor Frame");
+    if (type == "Message Frame" || type == "Output Dock")
+      type = i18n("Message Frame");//TODO: Remove the check against Output Dock after 3.2
+    if (type == "Message Window")
+      type = i18n("Message Window");
+    if (type == "Konsole")
+      type = i18n("Konsole");
     newPlugin->setOutputWindow(type);
+    newPlugin->setInput(config->readNumEntry("Input", 0));
+    newPlugin->setReadOnlyPart(config->readBoolEntry("ReadOnly", true));
 
-    m_plugins.insert(newPlugin->pluginName(), newPlugin);
+    m_plugins.insert(*it, newPlugin);
   }
   delete config;
 }
 
+/** Reads the plugin settings from the rc file */
+void QuantaPluginInterface::readConfig()
+{
+  m_plugins.clear();
+
+  // read the local plugins.rc
+  QString configFile = locateLocal("appdata", "plugins.rc");
+  if (QFileInfo(configFile).exists())
+      readConfigFile(configFile);
+  // read the global plugins.rc
+  configFile = qConfig.globalDataDir + resourceDir + "plugins.rc";
+  readConfigFile(configFile);
+}
+
 /** Writes the plugin settings to the rc file */
 void QuantaPluginInterface::writeConfig()
 {
@@ -141,24 +147,27 @@ void QuantaPluginInterface::writeConfig()
     if(curPlugin)
     {
       config->writeEntry("FileName", curPlugin->fileName());
-      QString type =  curPlugin->type();
-      if (type == i18n("KPart")) type = "KPart";
-      if (type == i18n("Command Line")) type = "Command Line";
-      config->writeEntry("Type", type);
+      config->writeEntry("Type", "KPart"); //not used, but just to be compatible
       config->writeEntry("Location", curPlugin->location());
-      config->writeEntry("Arguments", curPlugin->arguments());
       config->writeEntry("Icon", curPlugin->icon());
-      type = curPlugin->outputWindow();
-      if (type == i18n("Editor View")) type = "Editor View";
+      QString type = curPlugin->outputWindow();
+      if (type == i18n("Editor Tab")) type = "Editor Tab";
+      if (type == i18n("Editor Frame")) type = "Editor Frame";
+      if (type == i18n("Message Frame")) type = "Message Frame";
       if (type == i18n("Message Window")) type = "Message Window";
       if (type == i18n("Konsole")) type = "Konsole";
-	  if (type == i18n("Output Dock")) type = "Output Dock";
       config->writeEntry("OutputWindow", type);
+      config->writeEntry("Input", curPlugin->input());
       config->writeEntry("Standard", curPlugin->isStandard());
       if (curPlugin->isStandard()) config->writeEntry("Standard Name", curPlugin->standardName());
+      config->writeEntry("ReadOnly", curPlugin->readOnlyPart());
     }
   }
   config->sync();
+  if (config->isReadOnly())
+  {
+    kdWarning() << "Plugin config file " << locateLocal("appdata", "plugins.rc") << " is read only! Plugin settings were not saved!" << endl;
+  }
   delete config;
 }
 
@@ -177,6 +186,8 @@ void QuantaPluginInterface::setPlugins(QDict<QuantaPlugin> a_plugins)
 /** Returns TRUE if the plugin is available */
 bool QuantaPluginInterface::pluginAvailable(const QString &a_name)
 {
+  if (a_name.isEmpty())
+      return 0;
   QuantaPlugin *availPlugin = m_plugins.find(a_name);
   if(availPlugin && QuantaPlugin::validatePlugin(availPlugin))
     return TRUE;
@@ -184,14 +195,6 @@ bool QuantaPluginInterface::pluginAvailable(const QString &a_name)
   return FALSE;
 }
 
-#if 0
-/** Sets the plugin names */
-void QuantaPluginInterface::setPluginNames(QStringList a_pluginNames)
-{
-  m_pluginNames = a_pluginNames;
-}
-#endif
-
 /**  Gets the plugin names */
 QStringList QuantaPluginInterface::pluginNames() const
 {
@@ -216,35 +219,11 @@ QStringList QuantaPluginInterface::searchPaths()
   return qConfig.pluginSearchPaths;
 }
 
-QStringList QuantaPluginInterface::pluginTypes()
-{
-  QStringList types;
-  types << i18n("KPart");
-  types << i18n("Command Line");
-
-  return types;
-}
-
-QStringList QuantaPluginInterface::outputWindows(const QString &a_type)
-{
-  QStringList windows;
-
-  if(a_type == i18n("KPart"))
-  {
-    windows << i18n("Editor View") << i18n("Output Dock"); // TODO
-  }
-  else if(a_type == i18n("Command Line"))
-  {
-    windows << i18n("Message Window") << i18n("Konsole") << i18n("None");
-  }
-  else
-    qWarning("QuantaPluginInterface::outputWindows - Unknown type %s", a_type.latin1());
-  return windows;
-}
-
 /** Gets the plugin specified by a_name */
 QuantaPlugin *QuantaPluginInterface::plugin(const QString &a_name)
 {
+  if (a_name.isEmpty())
+      return 0;
   return m_plugins[a_name];
 }
 
