@@ -2,9 +2,8 @@
                           project.h  -  description
                              -------------------
     begin                : Thu Mar 16 2000
-    copyright            : (C) 2000 by Yacovlev Alexander & Dmitry Poplavsky
-                           (C) 2001-2003 by Andras Mantia
-    email                : pdima@mail.univ.kiev.ua, amantia@freemail.hu
+    copyright            : (C) 2000 by Yacovlev Alexander & Dmitry Poplavsky <pdima@mail.univ.kiev.ua>
+                           (C) 2001-2003 by Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -23,9 +22,13 @@
 #include <qbuffer.h>
 #include <qwidget.h>
 #include <qstringlist.h>
+#include <qregexp.h>
 
+#include <kdeversion.h>
 #include <kio/job.h>
+#include <kurl.h>
 
+#include "projecturl.h"
 
 /**project
   *@author Yacovlev Alexander & Dmitry Poplavsky & Andras Mantia
@@ -36,7 +39,11 @@ class QWidgetStack;
 
 class KConfig;
 class KTempFile;
+#if KDE_VERSION < KDE_MAKE_VERSION(3,1,92)
+class KQRecentFilesAction;
+#else
 class KRecentFilesAction;
+#endif
 
 class ProjectNewWeb;
 class ProjectNewLocal;
@@ -45,36 +52,49 @@ class ProjectNewGeneral;
 
 class CopyTo;
 
-class Project : public QWidget  {
+class Project : public QObject  {
    Q_OBJECT
 public:
-	Project( QWidget *parent=0, const char *name=0);
-	~Project();
-	
-	bool hasProject();
-	KURL::List fileNameList(bool check = false);
-	void loadProjectXML();
+
+  /**
+   *  since this class is a singleton you must use this function to access it
+   *
+   *  the parameter are only used at the first call to create the class
+   *
+   */
+  static Project* const ref()
+  {
+    static Project *m_ref;
+    if (!m_ref) m_ref = new Project ();
+    return m_ref;
+  }
+
+  ~Project();
+
+  bool hasProject() {return !projectName.isNull();};
+
+  KURL::List fileNameList(bool check = false);
 
   void insertFile( const KURL& nameURL, bool repaint );
-  void insertFiles( const KURL& pathURL, const QString& mask );
-  void insertFiles( KURL::List files );
-
-  bool createEmptyDom();
-
   void readConfig(KConfig *);
   void readLastConfig(KConfig *c=0);
   void writeConfig(KConfig *);
   /** No descriptions */
-  bool isModified() {return modified;}
-  void setModified(bool b);
+  bool isModified() {return m_modified;}
+  void setModified(bool modified);
   /** Returns the relative url with the prefix inserted. */
   KURL urlWithPrefix(const KURL& url);
-  /** Write property of QString defaultDTD. */
-  virtual void setDefaultDTD( const QString& p_defaultDTD);
+  bool contains(const KURL &url);
   /** Read property of QString defaultDTD. */
-  virtual const QString& defaultDTD();
+  virtual const QString& defaultDTD() {return m_defaultDTD;}
   virtual const QString& defaultEncoding() {return m_defaultEncoding;}
-  virtual const QString& newFileType() {return m_newFileType;}
+
+  /** Returns the project's base URL if it exists,
+   * the HOME dir if there is no project and no opened document
+   * (or the current  opened document was not saved yet),
+   * and the base URL of the opened document, if it is saved somewhere.
+   */
+  KURL projectBaseURL();
 
 public slots:
 
@@ -92,19 +112,19 @@ public slots:
   void slotAddDirectory();
   void slotAddDirectory(const KURL& dirURL, bool showDlg = true);
   void slotInsertFile(const KURL& url);
-  void slotInsertFilesAfterCopying(const KURL& url, CopyTo*);
-  void slotRenameFinished( KIO::Job *);
+  void slotInsertFilesAfterCopying(const KURL::List& a_url);
+  void slotDeleteCopytoDlg(CopyTo *);
 
-	void slotRename(const KURL& url);
-	void slotRemove(const KURL& urlToRemove);
+  /** if somewhere something was renamed */
+  void slotRenamed(const KURL& oldURL, const KURL& newURL);
+  void slotRemove(const KURL& urlToRemove);
 
-	void slotAcceptCreateProject();
+  void slotAcceptCreateProject();
 
   void slotSelectProjectType(const QString &);
 
-  void slotEnableMessages();
-  void slotDisableMessages();
-  void slotGetMessages(QString);
+  void slotEnableMessages(bool enable);
+  void slotGetMessages(const QString&);
 
   void slotRescanPrjDir();
   /** Saves a project view (group of files & toolbars) asking for a name if askForName==true. */
@@ -113,34 +133,30 @@ public slots:
   void slotOpenProjectView();
   /** Saves a project view (group of files & toolbars) without asking for a name. */
   void slotSaveProjectView();
+  /** Deletes a project view */
+  void slotDeleteProjectView();
+  void slotFileDescChanged(const KURL& url, const QString& desc);
 
 signals:
 
-	void openFile( const KURL&, const QString& );
-	void closeFiles();
+  void openFile( const KURL&, const QString& );
+  void closeFile( const KURL&);
+  void closeFiles();
 
-	void setBaseURL( const KURL& url );
-	void setProjectName( QString );
+  void showTree();
+  void reloadTree(const ProjectUrlList &, bool);
 
-	void showTree();
-	void reloadTree(const KURL::List &, bool);
-	
   void setLocalFiles( bool );
 
-  void messages( QString );
-  void selectMessageWidget();
-  void disableMessageWidget();
+  void messages(const QString& );
+  void enableMessageWidget(bool);
 
   void saveAllFiles();
   void newStatus();
   void statusMsg(QString);
-//  void checkOpenAction(bool);
   /** No descriptions */
-  void removeFromProject(int);
-  /** No descriptions */
-  void newProjectLoaded();
-  /** No descriptions */
-  void templateURLChanged(const KURL &);
+  void newProjectLoaded(const QString &, const KURL &, const KURL &);
+  void hideSplash();
 
 public:
   QDomDocument dom;
@@ -149,7 +165,6 @@ public:
   QString projectName;
 
   KURL baseURL;
-  KURL remoteDir;
   KURL templateURL;
   KURL toolbarURL;
 
@@ -158,8 +173,12 @@ public:
 
   QString email;
   QString author;
-  
+
+#if KDE_VERSION < KDE_MAKE_VERSION(3,1,92)
+  KQRecentFilesAction *projectRecent;
+#else
   KRecentFilesAction *projectRecent;
+#endif
 
     /** Holds the upload password. It is not saved, and it is lost after the project is closed. */
   QString passwd;
@@ -167,32 +186,45 @@ public:
   bool keepPasswd;
 
 private:
-	QWizard *wiz;
-	QWidgetStack *stack;
+
+  /** The constructor is privat because we use singleton patter.
+   *  If you need the class use Project::ref() for
+   *  construction and reference
+   */
+  Project();
+  void loadProjectXML();
+
+  bool createEmptyDom();
+  void insertFiles( const KURL& pathURL, const QString& mask );
+  void insertFiles( KURL::List files );
+  QWizard *wiz;
+  QWidgetStack *stack;
   QString currentProjectView;
-	
-	ProjectNewGeneral		*png;
-	ProjectNewLocal		  *pnl;
-	ProjectNewWeb 			*pnw;
-	ProjectNewFinal 		*pnf;
-	
-	KConfig *config;
-	
-	bool modified;
-	bool olfwprj; //for internal use
-	
+
+  ProjectNewGeneral    *png;
+  ProjectNewLocal      *pnl;
+  ProjectNewWeb       *pnw;
+  ProjectNewFinal     *pnf;
+
+  KConfig *config;
+
+  bool m_modified;
+  bool storePasswdInFile;
+
   QBuffer buff;
+  QRegExp excludeRx;
+  QStringList excludeList;
+
 protected: // Protected attributes
   /** Default DTD for this project. */
   QString m_defaultDTD;
   QString m_defaultEncoding;
-  QString m_newFileType;
-  /** The old name of the url. (Used when renaming/removing an url from the project). */
-  KURL oldURL;
-  /** The new name of the url (used when renaming an url). */
-  KURL newURL;
+  ProjectUrlList m_projectFiles; //stores the last result of fileNameList call
 
   void openCurrentView();
+  /** pre-sets some variables */
+  void init();
+
 };
 
 #endif
