@@ -2,9 +2,8 @@
                           projectnewlocal.cpp  -  description
                              -------------------
     begin                : Fri Oct 27 2000
-    copyright            : (C) 2000 by Dmitry Poplavsky & Alexander Yakovlev & Eric Laffoon
-                           (C) 2001, 2002 Andras Mantia <amantia@freemail.hu>
-    email                : pdima@users.sourceforge.net,yshurik@penguinpowered.com,sequitur@easystreet.com
+    copyright            : (C) 2000 by Dmitry Poplavsky & Alexander Yakovlev & Eric Laffoon <pdima@users.sourceforge.net,yshurik@penguinpowered.com,sequitur@easystreet.com>
+                           (C) 2001, 2002 Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -33,38 +32,40 @@
 #include <kprogress.h>
 #include <kmimetype.h>
 #include <kdeversion.h>
+#include <kurlrequesterdlg.h>
+#include <kurlrequester.h>
 
 //app includes
 #include "projectnewlocal.h"
 #include "projectnewgeneral.h"
-#include "../dialogs/copyto.h"
-#include "../qextfileinfo.h"
-#include "../treeviews/uploadtreefolder.h"
-#include "../treeviews/uploadtreeview.h"
-#include "../resource.h"
-#include "../quantacommon.h"
+#include "copyto.h"
+#include "qextfileinfo.h"
+#include "uploadtreefolder.h"
+#include "uploadtreeview.h"
+#include "resource.h"
+#include "quantacommon.h"
 
 ProjectNewLocal::ProjectNewLocal(QWidget *parent, const char *name )
-	: ProjectNewLocalS(parent,name)
+  : ProjectNewLocalS(parent,name)
 {
-	imagelabel->setPixmap( UserIcon("wiznewprjloc") );
+  imagelabel->setPixmap( UserIcon("wiznewprjloc") );
 
-//	listView->setColumnAlignment(1,Qt::AlignRight);
+//  listView->setColumnAlignment(1,Qt::AlignRight);
   listView->setColumnText(1, i18n("Add"));
   listView->removeColumn(2);
   listView->removeColumn(2);
 
-	mask->setText("*");
+  mask->setText("*");
 
-	checkInsertWeb->setChecked( true );
+  checkInsertWeb->setChecked( true );
 
-	connect( checkInsert, SIGNAL(toggled(bool)), this, SLOT(slotSetFiles(bool)));
-	connect( checkInsertWeb, SIGNAL(toggled(bool)), this, SLOT(slotSetFiles(bool)));
-	connect( checkInsertWithMask, SIGNAL(toggled(bool)), this, SLOT(slotSetFiles(bool)));
+  connect( checkInsert, SIGNAL(toggled(bool)), this, SLOT(slotSetFiles(bool)));
+  connect( checkInsertWeb, SIGNAL(toggled(bool)), this, SLOT(slotSetFiles(bool)));
+  connect( checkInsertWithMask, SIGNAL(toggled(bool)), this, SLOT(slotSetFiles(bool)));
 
-	connect(addFiles, SIGNAL(clicked()),this,SLOT(slotAddFiles()));
-	connect(addFolder, SIGNAL(clicked()),this,SLOT(slotAddFolder()));
-	connect(clearList, SIGNAL(clicked()),this,SLOT(slotClearList()));
+  connect(addFiles, SIGNAL(clicked()),this,SLOT(slotAddFiles()));
+  connect(addFolder, SIGNAL(clicked()),this,SLOT(slotAddFolder()));
+  connect(clearList, SIGNAL(clicked()),this,SLOT(slotClearList()));
 }
 
 ProjectNewLocal::~ProjectNewLocal(){
@@ -74,7 +75,7 @@ void ProjectNewLocal::setBaseURL(const KURL& a_baseURL)
 {
   baseURL = a_baseURL;
   baseURL.adjustPath(1);
-	checkInsert->setText(i18n("Insert files from \"%1\"").arg(baseURL.prettyURL()));
+  checkInsert->setText(i18n("Insert files from %1.").arg(baseURL.prettyURL(0, KURL::StripFileProtocol)));
   listView->clear();
   fileList.clear();
   checkInsert->setChecked(false);
@@ -83,7 +84,7 @@ void ProjectNewLocal::setBaseURL(const KURL& a_baseURL)
 KURL::List ProjectNewLocal::files()
 {
   //return fileList;
-	KURL::List r;
+  KURL::List r;
 
   QListViewItem *item;
   QListViewItemIterator it(listView);
@@ -109,13 +110,13 @@ KURL::List ProjectNewLocal::files()
 
 KURL::List ProjectNewLocal::projectFiles()
 {
-	KURL::List list;
+  KURL::List list;
 
   if (!QExtFileInfo::exists(baseURL) ||
       !baseURL.path().endsWith("/")  ||
       !checkInsert->isChecked() ) return list;
 
-	QString fmask = "*";
+  QString fmask = "*";
   if ( checkInsertWeb->isChecked() )
   {
     KMimeType::List list = KMimeType::allMimeTypes();
@@ -141,28 +142,29 @@ KURL::List ProjectNewLocal::projectFiles()
     fmask = mask->text();
   }
 
-	list = QExtFileInfo::allFilesRelative( baseURL, fmask);
+  list = QExtFileInfo::allFilesRelative( baseURL, fmask);
 
-	return list;
+  return list;
 }
 
 void ProjectNewLocal::slotSetFiles(bool)
 {
-	if ( checkInsert->isChecked() )
+  if ( checkInsert->isChecked() )
   {
-  	KURL::List files = projectFiles();
-    progressBar->setTotalSteps(files.count()-1);
+    KURL::List files = projectFiles();
+    progressBar->setTotalSteps(files.count() - 1);
     progressBar->setTextEnabled(true);
-	  for (uint i = 0; i < files.count(); i++)
-  	{
-	     if ( !fileList.contains(files[i]) )
+    for (uint i = 0; i < files.count(); i++)
+    {
+       if ( !fileList.contains(files[i]))
        {
          fileList.append(files[i]);
-         QListViewItem *it = listView->addItem(files[i], "", "");
+         QListViewItem *it = listView->addItem(files[i], KFileItem(KFileItem::Unknown, KFileItem::Unknown, KURL()));
          if (it)  it->setSelected(true);
          progressBar->setValue(i);
        }
-	  }
+    }
+    progressBar->setTotalSteps(1);
     progressBar->setValue(0);
     progressBar->setTextEnabled(false);
     listView->checkboxTree();
@@ -179,49 +181,55 @@ void ProjectNewLocal::resizeEvent ( QResizeEvent *t )
 void ProjectNewLocal::slotAddFiles()
 {
   QExtFileInfo::createDir( baseURL );
-	KURL::List list = KFileDialog::getOpenURLs(
-		baseURL.url(),	i18n("*"), this, i18n("Insert Files in Project"));
+  KURL::List list = KFileDialog::getOpenURLs(
+    baseURL.url(),  i18n("*"), this, i18n("Insert Files in Project"));
 
-	if ( !list.isEmpty() )
+  if ( !list.isEmpty() )
   {
-  	KURL u = list.first();
+    KURL u = list.first();
 
-  	u = QExtFileInfo::toRelative( u, baseURL );
+    u = QExtFileInfo::toRelative( u, baseURL );
 
-  	if ( u.path().startsWith("..") || u.path().startsWith("/"))
-  	{
-  		CopyTo *dlg = new CopyTo( baseURL, this, i18n("Files: copy to project...") );
+    if ( u.path().startsWith("..") || u.path().startsWith("/"))
+    {
+      KURLRequesterDlg *urlRequesterDlg = new KURLRequesterDlg( baseURL.prettyURL(), this, "");
+      urlRequesterDlg->setCaption(i18n("Files: Copy to Project"));
+      urlRequesterDlg->urlRequester()->setMode( KFile::Directory | KFile::ExistingOnly);
+      urlRequesterDlg->exec();
+      KURL destination = urlRequesterDlg->selectedURL();
+      delete urlRequesterDlg;
 
-      	if ( dlg->exec() )
-      	{
-         		list = dlg->copy( list );
-            connect(dlg, SIGNAL(addFilesToProject(const KURL&,CopyTo*)),
-                         SLOT(slotInsertFilesAfterCopying(const KURL&,CopyTo*)));
-            return;
-       	} else
-       	{
-      		delete dlg;
-         	 	return;
-       	}
-       	delete dlg;
-  	}
+      if ( !destination.isEmpty())
+      {
+        CopyTo *dlg = new CopyTo( baseURL);
+        connect(dlg, SIGNAL(addFilesToProject(const KURL::List&)),
+                     SLOT  (slotInsertFilesAfterCopying(const KURL::List&)));
+        connect(dlg, SIGNAL(deleteDialog(CopyTo *)),
+                     SLOT  (slotDeleteCopyToDlg(CopyTo *)));
+        list = dlg->copy( list, destination );
+        return;
+      } else
+      {
+        return;
+      }
+    }
 
-    progressBar->setTotalSteps(list.count()-1);
+    progressBar->setTotalSteps(list.count() - 1);
     progressBar->setTextEnabled(true);
-  	for (uint i = 0; i < list.count(); i++)
-  	{
+    for (uint i = 0; i < list.count(); i++)
+    {
        list[i] = QExtFileInfo::toRelative(list[i], baseURL);
-  	   if (!fileList.contains(list[i]))
+       if (!fileList.contains(list[i]))
        {
          fileList.append(list[i]);
-         QListViewItem *it = listView->addItem(list[i], "", "");
+         QListViewItem *it = listView->addItem(list[i], KFileItem(KFileItem::Unknown, KFileItem::Unknown, KURL()));
          if (it)  it->setSelected(true);
          progressBar->setValue(i);
        }
-  	}
-   progressBar->setValue(0);
-   progressBar->setTextEnabled(false);
-
+    }
+    progressBar->setTotalSteps(1);
+    progressBar->setValue(0);
+    progressBar->setTextEnabled(false);
   }
 }
 
@@ -232,66 +240,77 @@ void ProjectNewLocal::slotAddFolder()
 //I think this is a KDE bug
   QExtFileInfo::createDir( baseURL );
   KURL dirURL ;
-  #if KDE_VERSION < 308
-    QString dirName = KFileDialog::getExistingDirectory(
-	   	baseURL.url(),  this, i18n("Insert Directory in Project"));
-    QuantaCommon::setUrl(dirURL, dirName);
-  #else
-     dirURL = KFileDialog::getExistingURL(
-	   	baseURL.url(),  this, i18n("Insert Directory in Project"));
-  #endif
+  dirURL = KFileDialog::getExistingURL(
+           baseURL.url(),  this, i18n("Insert Directory in Project"));
 
-	if ( !dirURL.isEmpty() )
+  if ( !dirURL.isEmpty() )
   {
     dirURL.adjustPath(1);
 
-   	KURL sdir = dirURL;
+    KURL sdir = dirURL;
     sdir = QExtFileInfo::toRelative( sdir, baseURL);
 
     if ( sdir.path().startsWith("..") || sdir.path().startsWith("/") )
     {
-  	  CopyTo *dlg = new CopyTo( baseURL, this, i18n("%1: copy to project...").arg(dirURL.prettyURL()) );
 
-      if ( dlg->exec() )
+      KURLRequesterDlg *urlRequesterDlg = new KURLRequesterDlg( baseURL.prettyURL(), this, "");
+      urlRequesterDlg->setCaption(i18n("%1: Copy to Project").arg(dirURL.prettyURL(0, KURL::StripFileProtocol)));
+      urlRequesterDlg->urlRequester()->setMode( KFile::Directory | KFile::ExistingOnly);
+      urlRequesterDlg->exec();
+      KURL destination = urlRequesterDlg->selectedURL();
+      delete urlRequesterDlg;
+
+      if ( !destination.isEmpty())
       {
-        dirURL = dlg->copy(dirURL);
-        connect(dlg, SIGNAL(addFilesToProject(const KURL&,CopyTo*)),
-                     SLOT(slotInsertFilesAfterCopying(const KURL&,CopyTo*)));
+        CopyTo *dlg = new CopyTo( baseURL);
+        connect(dlg, SIGNAL(addFilesToProject(const KURL::List&)),
+                     SLOT  (slotInsertFilesAfterCopying(const KURL::List&)));
+        connect(dlg, SIGNAL(deleteDialog(CopyTo *)),
+                     SLOT  (slotDeleteCopyToDlg(CopyTo *)));
+        dirURL = dlg->copy(dirURL, destination);
         return;
       } else
       {
-        delete dlg;
         return;
       }
-      delete dlg;
     }
 
-    slotInsertFilesAfterCopying(dirURL, 0);
+    slotInsertFilesAfterCopying(dirURL);
   }
 }
 
-void ProjectNewLocal::slotInsertFilesAfterCopying(const KURL& rdir, CopyTo* dlg)
+void ProjectNewLocal::slotDeleteCopyToDialog(CopyTo* dlg)
 {
-  KURL dirURL = rdir;
 //The CopyTo dlg is deleted only here!!
   if (dlg) delete dlg;
-  dirURL.adjustPath(1);
-  KURL::List files = QExtFileInfo::allFilesRelative( dirURL, "*");
-  progressBar->setTotalSteps(files.count()-1);
-  progressBar->setTextEnabled(true);
-  for (uint i = 0; i < files.count(); i++)
-	{
-     if ( !fileList.contains(files[i]) )
-     {
-       fileList.append(files[i]);
-       QListViewItem *it = listView->addItem(files[i], "", "");
-       if (it)  it->setSelected(true); 
-       progressBar->setValue(i);
-     }
+}
+
+void ProjectNewLocal::slotInsertFilesAfterCopying(const KURL::List& a_urlList)
+{
+  KURL::List::ConstIterator it;
+  KURL dirURL;
+  for (it = a_urlList.begin(); it != a_urlList.end(); ++it)
+  {
+    dirURL = *it;
+   // dirURL.adjustPath(1);
+    KURL::List files = QExtFileInfo::allFilesRelative(dirURL, "*");
+    progressBar->setTotalSteps(files.count() - 1);
+    progressBar->setTextEnabled(true);
+    for (uint i = 0; i < files.count(); i++)
+    {
+      if ( !fileList.contains(files[i]))
+      {
+        fileList.append(files[i]);
+        QListViewItem *it = listView->addItem(files[i], KFileItem(KFileItem::Unknown, KFileItem::Unknown, KURL()));
+        if (it)  it->setSelected(true);
+        progressBar->setValue(i);
+      }
+    }
+    //listView->selectAll(false);
+    progressBar->setTotalSteps(1);
+    progressBar->setValue(0);
+    progressBar->setTextEnabled(false);
   }
-  //listView->selectAll(false);
-  progressBar->setValue(0);
-  progressBar->setTextEnabled(false);
 }
 
 /** No descriptions */
@@ -305,5 +324,5 @@ void ProjectNewLocal::slotClearList()
   fileList.clear();
   checkInsert->setChecked(false);
 }
-   
+
 #include "projectnewlocal.moc"
