@@ -1,9 +1,24 @@
-#include "rescanprj.moc"
+/***************************************************************************
+                          rescanprj.cpp -  description
+                             -------------------
+    begin                : ?
+    copyright            : (C) 2000 by Dmitry Poplavsky & Alexander Yakovlev & Eric Laffoon <pdima@users.sourceforge.net,yshurik@penguinpowered.com,sequitur@easystreet.com>
+                           (C) 2002, 2003 Andras Mantia <amantia@kde.org>
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
+
 // qt includes
 #include <qlistview.h>
 #include <qpushbutton.h>
 #include <qlayout.h>
-#include <qregexp.h>
 #include <qlabel.h>
 
 // kde includes
@@ -14,14 +29,15 @@
 #include <kprogress.h>
 
 // app includes
-#include "../qextfileinfo.h"
-#include "../quantacommon.h"
-#include "../treeviews/uploadtreefolder.h"
-#include "../treeviews/uploadtreeview.h"
-#include "../resource.h"
+#include "rescanprj.h"
+#include "qextfileinfo.h"
+#include "quantacommon.h"
+#include "uploadtreefolder.h"
+#include "uploadtreeview.h"
+#include "resource.h"
 
-RescanPrj::RescanPrj(KURL::List p_prjFileList, const KURL& p_baseURL, QWidget *parent, const char *name, bool modal )
-	: RescanPrjDir(parent,name,modal)
+RescanPrj::RescanPrj(ProjectUrlList p_prjFileList, const KURL& p_baseURL, QRegExp &p_excludeRx, QWidget *parent, const char *name, bool modal )
+  : RescanPrjDir(parent,name,modal)
 {
   setCaption(name);
 
@@ -30,6 +46,7 @@ RescanPrj::RescanPrj(KURL::List p_prjFileList, const KURL& p_baseURL, QWidget *p
   baseURL.adjustPath(1);
 
   prjFileList = p_prjFileList;
+  excludeRx = p_excludeRx;
 
   progressText->setText(i18n("Reading directory:"));
   KIO::ListJob *job = KIO::listRecursive( baseURL, false );
@@ -40,19 +57,25 @@ RescanPrj::RescanPrj(KURL::List p_prjFileList, const KURL& p_baseURL, QWidget *p
            this,SLOT  (slotListDone(KIO::Job *)));
 
 
-	connect( buttonSelect,   SIGNAL(clicked()),
-	         this,           SLOT(slotSelect()));
-	connect( buttonDeselect, SIGNAL(clicked()),
-	         this,           SLOT(slotDeselect()));
-	connect( buttonInvert,   SIGNAL(clicked()),
-	         this,           SLOT(slotInvert()));
-	connect( buttonExpand,   SIGNAL(clicked()),
-	         this,           SLOT(slotExpand()));
-	connect( buttonCollapse, SIGNAL(clicked()),
-	         this,           SLOT(slotCollapse()));
+  connect( buttonSelect,   SIGNAL(clicked()),
+           this,           SLOT(slotSelect()));
+  connect( buttonDeselect, SIGNAL(clicked()),
+           this,           SLOT(slotDeselect()));
+  connect( buttonInvert,   SIGNAL(clicked()),
+           this,           SLOT(slotInvert()));
+  connect( buttonExpand,   SIGNAL(clicked()),
+           this,           SLOT(slotExpand()));
+  connect( buttonCollapse, SIGNAL(clicked()),
+           this,           SLOT(slotCollapse()));
 }
 
-RescanPrj::~RescanPrj(){
+RescanPrj::~RescanPrj()
+{
+  for (uint i = 0; i < urlList.count(); i++)
+  {
+    delete urlList[i].fileItem;
+  }
+  urlList.clear();
 }
 
 void RescanPrj::addEntries(KIO::Job *job,const KIO::UDSEntryList &list)
@@ -72,17 +95,16 @@ void RescanPrj::addEntries(KIO::Job *job,const KIO::UDSEntryList &list)
   {
     KFileItem item( *it, url, false, true );
     name = item.name();
-    if ( ! name.isEmpty() && name != dot && name != dotdot)
+    if ( ! name.isEmpty() && name != dot && name != dotdot && !excludeRx.exactMatch(name))
     {
       itemURL = item.url();
       if (item.isDir()) itemURL.adjustPath(1);
 //    itemURL = QExtFileInfo::toRelative(itemURL, baseURL);
-      itemURL.setPath(itemURL.path().replace(QRegExp(baseURL.path()),""));
+      itemURL.setPath(itemURL.path().replace(baseURL.path(),""));
       if (prjFileList.findIndex(itemURL) == -1 )
       {
         urlEntry.url = itemURL;
-        urlEntry.date = item.timeString();
-        urlEntry.size = QString("%1").arg( (long int)item.size() );
+        urlEntry.fileItem = new KFileItem(item);
         urlList.append(urlEntry);
       }
     }
@@ -126,7 +148,7 @@ void RescanPrj::slotCollapse()
 
 KURL::List RescanPrj::files()
 {
-	KURL::List r;
+  KURL::List r;
 
   QListViewItem *item;
   QListViewItemIterator it(listView);
@@ -160,13 +182,15 @@ void RescanPrj::slotListDone(KIO::Job *)
   for (uint i = 0; i < urlList.count(); i++)
   {
     urlEntry = urlList[i];
-    listView->addItem(urlEntry.url, urlEntry.size, urlEntry.date);
+    listView->addItem(urlEntry.url, *(urlEntry.fileItem));
     progress->advance(1);
   }
 
-  progress->setTotalSteps(1);  
+  progress->setTotalSteps(1);
   progress->setValue(0);
   progress->setTextEnabled(false);
-  slotSelect();
   progressText->setText(i18n("Progress:"));
+  slotSelect();
 }
+
+#include "rescanprj.moc"
