@@ -2,8 +2,8 @@
                           quantadoc.h  -  description
                              -------------------
     begin                :    9 13:29:57 EEST 2000
-    copyright            : (C) 2000 by Dmitry Poplavsky & Alexander Yakovlev & Eric Laffoon
-    email                : pdima@users.sourceforge.net,yshurik@linuxfan.com,sequitur@easystreet.com
+    copyright            : (C) 2000 by Dmitry Poplavsky & Alexander Yakovlev & Eric Laffoon <pdima@users.sourceforge.net,yshurik@linuxfan.com,sequitur@easystreet.com>
+                           (C) 2001-2003 Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,40 +18,29 @@
 #ifndef QUANTADOC_H
 #define QUANTADOC_H
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 // include files for QT
 #include <qptrlist.h>
 #include <qdict.h>
-#include <qobject.h>
-#include <qstring.h>
-
-#include <kurl.h>
 
 // forward declaration of the Quanta classes
-class QuantaApp;
-class QuantaView;
 class Document;
-
 class KConfig;
-class KDirWatch;
+class KURL;
 
 class QuantaDoc : public QObject
 {
   Q_OBJECT
 
-friend class QuantaApp;
-friend class QuantaView;
-
 public:
 
-  QuantaDoc( QWidget *parent, const char *name=0);
+  QuantaDoc(QWidget *parent, const char *name=0);
   ~QuantaDoc();
 
-  void openDocument (const KURL&, QString encoding = QString::null);
-  bool saveDocument (const KURL&);
+  bool newDocument(const KURL&, bool switchToExisting = true);
+  void openDocument(const KURL&, const QString& a_encoding = QString::null, bool switchToExisting = true);
+  bool saveDocument(const KURL&);
   void closeDocument();
 
   void prevDocument();
@@ -60,45 +49,50 @@ public:
   bool isModified();
   bool isModifiedAll();
   void setModified(bool flag = true);
+  /** Check if url is opened or not. */
+  Document* isOpened(const KURL& url);
 
-  /// "save modified" - asks the user
-  /// for saving if the document is modified
+  // "save modified" - asks the user
+  // for saving if the document is modified
   bool saveModified();
   bool saveAll(bool dont_ask=true);
 
-  Document *write();
-  Document *newWrite();
+  // for kwrites
+  void readConfig(KConfig *);
+  void writeConfig(KConfig *);
 
-	// for kwrites
-	void  readConfig( KConfig * );
-	void writeConfig( KConfig * );
-
-	KURL::List openedFiles(bool noUntitled=true);
-  void changeFileTabName(KURL newURL = KURL() );
+  KURL::List openedFiles(bool noUntitled=true);
+  void changeFileTabName(const KURL& newURL = KURL());
 
 private:
-  bool newDocument (const KURL&);
-  /** Check if url is opened or not. */
-  Document* isOpened(const KURL& url);
+  Document *write() const;
+  Document *newWrite();
 
 public slots:
   /** close documents. */
   void closeAll();
   /** show popup menu with list of attributes for current tag */
-  void slotInsertAttrib      ( int id );
+  void slotInsertAttrib( int id );
   void slotAttribPopup();
 
   void undoHistory();
   void invertSelect();
   /** Called when a file on the disk has changed. */
   void slotFileDirty(const QString& fileName);
+  void slotOpeningCompleted();  
+  void slotSavingCompleted();  
+  void slotSavingFailed(const QString& error);  
 
 signals:
   void newStatus();
   void title(QString);
+  void hideSplash();
+  void documentClosed();
 
 private:
-    KPopupMenu *attribMenu;
+  KPopupMenu *attribMenu;
+  bool m_saveResult;
+  bool m_eventLoopStarted;
 };
 
 #endif // QUANTADOC_H
