@@ -2,46 +2,53 @@
                           tagmaildlg.cpp  -  description
                              -------------------
     begin                : Sat Nov 24 2001
-    copyright            : (C) 2001-2002 by Andras Mantia
-    email                : amantia@freemail.hu
+    copyright            : (C) 2001-2002 by Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
+ *   the Free Software Foundation; version 2 of the License.               *
  *   (at your option) any later version.                                   *
- *                                                                         *
  ***************************************************************************/
 
+
 #include "tagmaildlg.h"
 #include "listdlg.h"
-#include "../resource.h"
+#include "resource.h"
+#include "quantacommon.h"
 
 //kde includes
 #include <kapplication.h>
+#include <kdialog.h>
+#include <kiconloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kabc/stdaddressbook.h>
 
 //qt includes
 #include <qlineedit.h>
-#include <qpushbutton.h>
+#include <kpushbutton.h>
 #include <qstringlist.h>
 #include <qregexp.h>
 
 
 TagMailDlg::TagMailDlg(QWidget *parent, const char *name)
-	:TagMail(parent,name,true)
+  :TagMail(parent, name)
 {
   setCaption(name);
+#if KDE_IS_VERSION(3,1,90)
+  setModal(true);
+#endif
 
   connect( buttonOk,     SIGNAL(clicked()), SLOT(accept()) );
   connect( buttonCancel, SIGNAL(clicked()), SLOT(reject()) );
   connect( buttonHelp,SIGNAL(clicked()),this,SLOT(slotShowHelp()));
   connect( buttonAddressSelect, SIGNAL(clicked()), SLOT(slotSelectAddress()) );
-
+  buttonOk->setIconSet(SmallIconSet("button_ok"));
+  buttonCancel->setIconSet(SmallIconSet("button_cancel"));
+  buttonHelp->setIconSet(SmallIconSet("help"));
   lineEmail->setFocus();
 }
 
@@ -58,30 +65,30 @@ void TagMailDlg::slotSelectAddress()
   for( it = addressBook->begin(); it != addressBook->end(); ++it ) {
     QStringList emails = (*it).emails();
     QString n = (*it).prefix() + " " +
-		(*it).givenName() + " " +
-		(*it).additionalName() + " " +
-	        (*it).familyName() + " " +
-		(*it).suffix();
+    (*it).givenName() + " " +
+    (*it).additionalName() + " " +
+          (*it).familyName() + " " +
+    (*it).suffix();
     n = n.simplifyWhiteSpace();
     for( unsigned int i = 0; i < emails.count(); ++i ) {
       if (!emails[i].isEmpty()) {
-	if (n.isEmpty() || (emails[i].find( "<" ) != -1))
-	  addr = "";
-	else { /* do we really need quotes around this name ? */
-	  if (n.find(QRegExp("[^ 0-9A-Za-z\\x0080-\\xFFFF]")) != -1)
+  if (n.isEmpty() || (emails[i].find( "<" ) != -1))
+    addr = "";
+  else { /* do we really need quotes around this name ? */
+    if (n.find(QRegExp("[^ 0-9A-Za-z\\x0080-\\xFFFF]")) != -1)
       addr = qConfig.attrValueQuotation + n + qConfig.attrValueQuotation + " ";
-	  else
-	    addr = n + " ";
-	}
-	email = emails[i];
-	if (!addr.isEmpty() && (email.find( "<" ) == -1)
-	    && (email.find( ">" ) == -1)
-	    && (email.find( "," ) == -1))
-	  addr += "<" + email + ">";
-	else
-	  addr += email;
-	addr.stripWhiteSpace();
-	result.append( addr );
+    else
+      addr = n + " ";
+  }
+  email = emails[i];
+  if (!addr.isEmpty() && (email.find( "<" ) == -1)
+      && (email.find( ">" ) == -1)
+      && (email.find( "," ) == -1))
+    addr += "<" + email + ">";
+  else
+    addr += email;
+  addr.stripWhiteSpace();
+  result.append( addr );
       }
     }
   }
