@@ -2,8 +2,8 @@
                           docitem.cpp  -  description
                              -------------------
     begin                : Fri Mar 3 2000
-    copyright            : (C) 2000 by Yacovlev Alexander & Dmitry Poplavsky
-    email                : pdima@mail.univ.kiev.ua
+    copyright            : (C) 2000 by Yacovlev Alexander & Dmitry Poplavsky <pdima@mail.univ.kiev.ua>
+                           (C) 2002 Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,19 +15,21 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "docitem.h"
-#include "kconfig.h"
 #include "qstrlist.h"
 
+#include "kconfig.h"
+
+#include "docitem.h"
+
 DocItem::DocItem(QListViewItem *parent, QString _name, QString _url)
-  : QListViewItem(parent)
+  : KListViewItem(parent)
 {
   url = _url;
   name = _name;
 }
 
 DocItem::DocItem(QListView *parent, QString _name, QString _url)
-  : QListViewItem(parent)
+  : KListViewItem(parent)
 {
   url = _url;
   name = _name;
@@ -39,9 +41,12 @@ DocItem::~DocItem()
 }
 
 
-QString DocItem::text( int ) const
+QString DocItem::text( int i) const
 {
-  return name.data();
+  if (i == 0)
+    return name;
+  else
+    return "";
 }
+//#include "docitem.moc"
 
-#include "docitem.moc"
