@@ -2,16 +2,14 @@
                           uploadtreefile.cpp  -  description
                              -------------------
     begin                : Sun Aug 25 2002
-    copyright            : (C) 2002 by Andras Mantia
-    email                : amantia@freemail.hu
+    copyright            : (C) 2002, 2003 by Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   the Free Software Foundation; version 2 of the License.               *
  *                                                                         *
  ***************************************************************************/
 
@@ -21,30 +19,33 @@
 #include <qfileinfo.h>
 
 // KDE includes
+#include <kfileitem.h>
 #include <kiconloader.h>
 #include <kurl.h>
 
 // app includes
 #include "uploadtreefile.h"
-#include "../resource.h"
+#include "resource.h"
 
-UploadTreeFile::UploadTreeFile( UploadTreeFolder *parent, const KURL &a_url, QString date, QString size )
-    : KListViewItem( parent, a_url.fileName(), "", date, size )
+UploadTreeFile::UploadTreeFile( UploadTreeFolder *parent, const KURL &a_url, const KFileItem &a_fileItem)
+    : KListViewItem( parent, a_url.fileName(), "", QString("%1").arg( (long int)a_fileItem.size() ), a_fileItem.timeString())
 {
-	m_url = a_url;
-	isDir = false;
+  m_url = a_url;
+  isDir = false;
   parentFolder = parent;
+  m_fileItem = new KFileItem(a_fileItem);
 
   setWhichPixmap("check_clear");
   setText(0, m_url.fileName());
 }
 
-UploadTreeFile::UploadTreeFile( QListView *parent, const KURL &a_url, QString date, QString size )
-    : KListViewItem( parent, a_url.fileName(), "", date, size )
+UploadTreeFile::UploadTreeFile( QListView *parent, const KURL &a_url, const KFileItem &a_fileItem)
+    : KListViewItem( parent, a_url.fileName(), "", QString("%1").arg( (long int)a_fileItem.size() ), a_fileItem.timeString())
 {
-	m_url = a_url;
-	isDir = false;
+  m_url = a_url;
+  isDir = false;
   parentFolder = 0L;
+  m_fileItem = new KFileItem(a_fileItem);
 
   //setPixmap( 1, SmallIcon("check") );
   setWhichPixmap("check_clear");
@@ -52,9 +53,18 @@ UploadTreeFile::UploadTreeFile( QListView *parent, const KURL &a_url, QString da
 }
 
 
-UploadTreeFile::~UploadTreeFile(){
+UploadTreeFile::~UploadTreeFile()
+{
+  delete m_fileItem;
 }
 
+mode_t UploadTreeFile::permissions()
+{
+  if (m_fileItem)
+      return m_fileItem->permissions();
+  else
+      return -1;
+}
 
 /** used for sorting */
 QString UploadTreeFile::key ( int, bool ) const
@@ -65,7 +75,7 @@ QString UploadTreeFile::key ( int, bool ) const
 //  return QFileInfo(key).extension()+key;
 }
 
-void UploadTreeFile::setWhichPixmap( QString pixmap )
+void UploadTreeFile::setWhichPixmap(const QString& pixmap )
 {
   setPixmap( 1, SmallIcon(pixmap) );
 }
