@@ -2,16 +2,14 @@
                           uploadtreefile.h  -  description
                              -------------------
     begin                : Sun Aug 25 2002
-    copyright            : (C) 2002 by Andras Mantia
-    email                : amantia@freemail.hu
+    copyright            : (C) 2002, 2003 by Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   the Free Software Foundation; version 2 of the License.               *
  *                                                                         *
  ***************************************************************************/
 
@@ -19,29 +17,35 @@
 #define UPLOADTREEFILE_H
 
 #include <klistview.h>
+#include <sys/types.h>
+
 #include "uploadtreefolder.h"
 
 /**
-  *@author George Vilches
+  *@author George Vilches & Andras Mantia
   */
 
-class UploadTreeFile : public KListViewItem  {
-public: 
-	UploadTreeFile( UploadTreeFolder *parent, const KURL &a_url, QString, QString);
-	UploadTreeFile( QListView *parent, const KURL &a_url, QString, QString );
-	~UploadTreeFile();
-	
-  void setWhichPixmap( QString );
+class KFileItem;
 
-	/** used for sorting */
-	virtual QString key ( int column, bool ascending ) const;
+class UploadTreeFile : public KListViewItem  {
+public:
+  UploadTreeFile( UploadTreeFolder *parent, const KURL &a_url, const KFileItem &a_fileItem);
+  UploadTreeFile( QListView *parent, const KURL &a_url, const KFileItem &a_fileItem);
+  ~UploadTreeFile();
+
+  void setWhichPixmap(const QString& pixmap);
+  mode_t permissions();
+
+  /** used for sorting */
+  virtual QString key ( int column, bool ascending ) const;
   /** No descriptions */
   KURL url();
 
 public:
-	UploadTreeFolder * parentFolder;
-	KURL m_url;
-	bool isDir;
+  UploadTreeFolder * parentFolder;
+  KURL m_url;
+  bool isDir;
+  KFileItem *m_fileItem;
 };
 
 #endif
