@@ -2,16 +2,14 @@
                           uploadtreeview.h  -  description
                              -------------------
     begin                : Sun Aug 25 2002
-    copyright            : (C) 2002 by Andras Mantia
-    email                : amantia@freemail.hu
+    copyright            : (C) 2002, 2003 by Andras Mantia <amantia@kde.org>
  ***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   the Free Software Foundation; version 2 of the License.               *
  *                                                                         *
  ***************************************************************************/
 
@@ -22,13 +20,13 @@
 #include <qpixmap.h>
 #include <qheader.h>
 
-#include "filemanage.h"
 #include "uploadtreefolder.h"
 #include "uploadtreefile.h"
 
+class KFileItem;
 
 /**
-  *@author George Vilches
+  *@author George Vilches & Andras Mantia
   */
 
 class UploadTreeView : public KListView {
@@ -36,7 +34,7 @@ class UploadTreeView : public KListView {
 public:
   UploadTreeView( QWidget *parent, const char *name=0L );
   ~UploadTreeView();
-  UploadTreeFile* addItem( const KURL &a_url, QString, QString );
+  UploadTreeFile* addItem( const KURL &a_url, const KFileItem &a_fileItem);
   QListViewItem* findItem( const QString& );
   int checkboxTree( QListViewItem *it = 0);
   void expandAll( QListViewItem * = 0 );
@@ -51,9 +49,12 @@ public slots:
   void slotSelectFile( );
   void selectAllUnderNode( QListViewItem *it, bool select );
 
+private slots:
+  void slotDoubleClicked(QListViewItem *, const QPoint &, int );
+
 private:
   UploadTreeFolder* findFolder( UploadTreeFolder *, const QString&);
-  UploadTreeFolder* printTree( UploadTreeFolder *, QString);
+  UploadTreeFolder* printTree( UploadTreeFolder *, const QString&);
 };
 
 #endif
